/****************************************************************************
** Meta object code from reading C++ file 'MarbleWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/MarbleWidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MarbleWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble12MarbleWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble12MarbleWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleWidget",
        "D-Bus Interface",
        "org.kde.MarbleWidget",
        "zoomChanged",
        "",
        "zoom",
        "distanceChanged",
        "distanceString",
        "tileLevelChanged",
        "level",
        "viewContextChanged",
        "ViewContext",
        "newViewContext",
        "themeChanged",
        "theme",
        "projectionChanged",
        "Projection",
        "mouseMoveGeoPosition",
        "mouseClickGeoPosition",
        "lon",
        "lat",
        "GeoDataCoordinates::Unit",
        "framesPerSecond",
        "fps",
        "regionSelected",
        "GeoDataLatLonBox",
        "boundingBox",
        "pluginSettingsChanged",
        "renderPluginInitialized",
        "RenderPlugin*",
        "renderPlugin",
        "visibleLatLonAltBoxChanged",
        "GeoDataLatLonAltBox",
        "visibleLatLonAltBox",
        "renderStatusChanged",
        "RenderStatus",
        "status",
        "renderStateChanged",
        "RenderState",
        "state",
        "highlightedPlacemarksChanged",
        "unit",
        "propertyValueChanged",
        "name",
        "value",
        "setRadius",
        "radius",
        "setZoom",
        "FlyToMode",
        "mode",
        "zoomView",
        "zoomViewBy",
        "zoomStep",
        "zoomIn",
        "zoomOut",
        "setDistance",
        "distance",
        "rotateBy",
        "deltaLon",
        "deltaLat",
        "centerOn",
        "animated",
        "GeoDataCoordinates",
        "point",
        "box",
        "GeoDataPlacemark",
        "placemark",
        "setCenterLatitude",
        "setCenterLongitude",
        "setHeading",
        "heading",
        "moveLeft",
        "moveRight",
        "moveUp",
        "moveDown",
        "goHome",
        "flyTo",
        "GeoDataLookAt",
        "lookAt",
        "setProjection",
        "projection",
        "setMapThemeId",
        "maptheme",
        "setPropertyValue",
        "setShowOverviewMap",
        "visible",
        "setShowScaleBar",
        "setShowCompass",
        "setShowClouds",
        "setShowSunShading",
        "setShowCityLights",
        "setLockToSubSolarPoint",
        "setSubSolarPointIconVisible",
        "setShowAtmosphere",
        "setShowCrosshairs",
        "setShowGrid",
        "setShowPlaces",
        "setShowCities",
        "setShowTerrain",
        "setShowOtherPlaces",
        "setShowRelief",
        "setShowIceLayer",
        "setShowBorders",
        "setShowRivers",
        "setShowLakes",
        "setShowFrameRate",
        "setShowBackground",
        "setShowTileId",
        "setShowRuntimeTrace",
        "showRuntimeTrace",
        "setShowDebugPolygons",
        "showDebugPolygons",
        "setShowDebugBatchRender",
        "showDebugBatchRender",
        "setShowDebugPlacemarks",
        "showDebugPlacemarks",
        "setDebugLevelTags",
        "debugLevelTags",
        "setLevelToDebug",
        "levelToDebug",
        "setMapQualityForViewContext",
        "MapQuality",
        "quality",
        "viewContext",
        "setViewContext",
        "setAnimationsEnabled",
        "enabled",
        "clearVolatileTileCache",
        "setVolatileTileCacheLimit",
        "kiloBytes",
        "creatingTilesStart",
        "TileCreator*",
        "creator",
        "description",
        "reloadMap",
        "downloadRegion",
        "QList<TileCoordsPyramid>",
        "notifyMouseClick",
        "x",
        "y",
        "setSelection",
        "QRect",
        "region",
        "setInputEnabled",
        "textureLayer",
        "TextureLayer*",
        "vectorTileLayer",
        "VectorTileLayer*",
        "updateMapTheme",
        "updateSystemBackgroundAttribute",
        "mapThemeId",
        "longitude",
        "latitude",
        "showOverviewMap",
        "showScaleBar",
        "showCompass",
        "showGrid",
        "showClouds",
        "showSunShading",
        "showCityLights",
        "isLockedToSubSolarPoint",
        "isSubSolarPointIconVisible",
        "showAtmosphere",
        "showCrosshairs",
        "showPlaces",
        "showCities",
        "showTerrain",
        "showOtherPlaces",
        "showRelief",
        "showIceLayer",
        "showBorders",
        "showRivers",
        "showLakes",
        "renderStatus",
        "volatileTileCacheLimit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'distanceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'tileLevelChanged'
        QtMocHelpers::SignalData<void(int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'viewContextChanged'
        QtMocHelpers::SignalData<void(ViewContext)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'projectionChanged'
        QtMocHelpers::SignalData<void(Projection)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 4 },
        }}),
        // Signal 'mouseMoveGeoPosition'
        QtMocHelpers::SignalData<void(const QString &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'mouseClickGeoPosition'
        QtMocHelpers::SignalData<void(qreal, qreal, GeoDataCoordinates::Unit)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 19 }, { QMetaType::QReal, 20 }, { 0x80000000 | 21, 4 },
        }}),
        // Signal 'framesPerSecond'
        QtMocHelpers::SignalData<void(qreal)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 23 },
        }}),
        // Signal 'regionSelected'
        QtMocHelpers::SignalData<void(const GeoDataLatLonBox &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Signal 'pluginSettingsChanged'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderPluginInitialized'
        QtMocHelpers::SignalData<void(RenderPlugin *)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Signal 'visibleLatLonAltBoxChanged'
        QtMocHelpers::SignalData<void(const GeoDataLatLonAltBox &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'renderStatusChanged'
        QtMocHelpers::SignalData<void(RenderStatus)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Signal 'renderStateChanged'
        QtMocHelpers::SignalData<void(const RenderState &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Signal 'highlightedPlacemarksChanged'
        QtMocHelpers::SignalData<void(qreal, qreal, GeoDataCoordinates::Unit)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 19 }, { QMetaType::QReal, 20 }, { 0x80000000 | 21, 41 },
        }}),
        // Signal 'propertyValueChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { QMetaType::Bool, 44 },
        }}),
        // Slot 'setRadius'
        QtMocHelpers::SlotData<void(int)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(int, FlyToMode)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(int)>(47, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(int, FlyToMode)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(int)>(50, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'zoomViewBy'
        QtMocHelpers::SlotData<void(int, FlyToMode)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 52 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'zoomViewBy'
        QtMocHelpers::SlotData<void(int)>(51, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void(FlyToMode)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void(FlyToMode)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setDistance'
        QtMocHelpers::SlotData<void(qreal)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 56 },
        }}),
        // Slot 'rotateBy'
        QtMocHelpers::SlotData<void(const qreal, const qreal, FlyToMode)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 58 }, { QMetaType::QReal, 59 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'rotateBy'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(57, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QReal, 58 }, { QMetaType::QReal, 59 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const qreal, const qreal, bool)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 19 }, { QMetaType::QReal, 20 }, { QMetaType::Bool, 61 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(60, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QReal, 19 }, { QMetaType::QReal, 20 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &, bool)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 }, { QMetaType::Bool, 61 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(60, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataLatLonBox &, bool)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 64 }, { QMetaType::Bool, 61 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataLatLonBox &)>(60, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 25, 64 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataPlacemark &, bool)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 66 }, { QMetaType::Bool, 61 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataPlacemark &)>(60, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 65, 66 },
        }}),
        // Slot 'setCenterLatitude'
        QtMocHelpers::SlotData<void(qreal, FlyToMode)>(67, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 20 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'setCenterLatitude'
        QtMocHelpers::SlotData<void(qreal)>(67, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QReal, 20 },
        }}),
        // Slot 'setCenterLongitude'
        QtMocHelpers::SlotData<void(qreal, FlyToMode)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 19 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'setCenterLongitude'
        QtMocHelpers::SlotData<void(qreal)>(68, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QReal, 19 },
        }}),
        // Slot 'setHeading'
        QtMocHelpers::SlotData<void(qreal)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 70 },
        }}),
        // Slot 'moveLeft'
        QtMocHelpers::SlotData<void(FlyToMode)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'moveLeft'
        QtMocHelpers::SlotData<void()>(71, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveRight'
        QtMocHelpers::SlotData<void(FlyToMode)>(72, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'moveRight'
        QtMocHelpers::SlotData<void()>(72, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveUp'
        QtMocHelpers::SlotData<void(FlyToMode)>(73, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'moveUp'
        QtMocHelpers::SlotData<void()>(73, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveDown'
        QtMocHelpers::SlotData<void(FlyToMode)>(74, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'moveDown'
        QtMocHelpers::SlotData<void()>(74, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'goHome'
        QtMocHelpers::SlotData<void(FlyToMode)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'goHome'
        QtMocHelpers::SlotData<void()>(75, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'flyTo'
        QtMocHelpers::SlotData<void(const GeoDataLookAt &, FlyToMode)>(76, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 77, 78 }, { 0x80000000 | 48, 49 },
        }}),
        // Slot 'flyTo'
        QtMocHelpers::SlotData<void(const GeoDataLookAt &)>(76, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 77, 78 },
        }}),
        // Slot 'setProjection'
        QtMocHelpers::SlotData<void(int)>(79, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 80 },
        }}),
        // Slot 'setProjection'
        QtMocHelpers::SlotData<void(Projection)>(79, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 80 },
        }}),
        // Slot 'setMapThemeId'
        QtMocHelpers::SlotData<void(const QString &)>(81, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 82 },
        }}),
        // Slot 'setPropertyValue'
        QtMocHelpers::SlotData<void(const QString &, bool)>(83, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { QMetaType::Bool, 44 },
        }}),
        // Slot 'setShowOverviewMap'
        QtMocHelpers::SlotData<void(bool)>(84, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowScaleBar'
        QtMocHelpers::SlotData<void(bool)>(86, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowCompass'
        QtMocHelpers::SlotData<void(bool)>(87, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowClouds'
        QtMocHelpers::SlotData<void(bool)>(88, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowSunShading'
        QtMocHelpers::SlotData<void(bool)>(89, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowCityLights'
        QtMocHelpers::SlotData<void(bool)>(90, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setLockToSubSolarPoint'
        QtMocHelpers::SlotData<void(bool)>(91, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setSubSolarPointIconVisible'
        QtMocHelpers::SlotData<void(bool)>(92, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowAtmosphere'
        QtMocHelpers::SlotData<void(bool)>(93, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowCrosshairs'
        QtMocHelpers::SlotData<void(bool)>(94, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowGrid'
        QtMocHelpers::SlotData<void(bool)>(95, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowPlaces'
        QtMocHelpers::SlotData<void(bool)>(96, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowCities'
        QtMocHelpers::SlotData<void(bool)>(97, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowTerrain'
        QtMocHelpers::SlotData<void(bool)>(98, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowOtherPlaces'
        QtMocHelpers::SlotData<void(bool)>(99, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowRelief'
        QtMocHelpers::SlotData<void(bool)>(100, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowIceLayer'
        QtMocHelpers::SlotData<void(bool)>(101, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowBorders'
        QtMocHelpers::SlotData<void(bool)>(102, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowRivers'
        QtMocHelpers::SlotData<void(bool)>(103, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowLakes'
        QtMocHelpers::SlotData<void(bool)>(104, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowFrameRate'
        QtMocHelpers::SlotData<void(bool)>(105, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowBackground'
        QtMocHelpers::SlotData<void(bool)>(106, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowTileId'
        QtMocHelpers::SlotData<void(bool)>(107, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setShowRuntimeTrace'
        QtMocHelpers::SlotData<void(bool)>(108, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'showRuntimeTrace'
        QtMocHelpers::SlotData<bool() const>(109, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowDebugPolygons'
        QtMocHelpers::SlotData<void(bool)>(110, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'showDebugPolygons'
        QtMocHelpers::SlotData<bool() const>(111, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowDebugBatchRender'
        QtMocHelpers::SlotData<void(bool)>(112, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'showDebugBatchRender'
        QtMocHelpers::SlotData<bool() const>(113, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowDebugPlacemarks'
        QtMocHelpers::SlotData<void(bool)>(114, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'showDebugPlacemarks'
        QtMocHelpers::SlotData<bool() const>(115, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setDebugLevelTags'
        QtMocHelpers::SlotData<void(bool)>(116, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'debugLevelTags'
        QtMocHelpers::SlotData<bool() const>(117, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setLevelToDebug'
        QtMocHelpers::SlotData<void(int)>(118, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'levelToDebug'
        QtMocHelpers::SlotData<int() const>(119, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setMapQualityForViewContext'
        QtMocHelpers::SlotData<void(MapQuality, ViewContext)>(120, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 121, 122 }, { 0x80000000 | 11, 123 },
        }}),
        // Slot 'setViewContext'
        QtMocHelpers::SlotData<void(ViewContext)>(124, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 123 },
        }}),
        // Slot 'setAnimationsEnabled'
        QtMocHelpers::SlotData<void(bool)>(125, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 126 },
        }}),
        // Slot 'clearVolatileTileCache'
        QtMocHelpers::SlotData<void()>(127, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setVolatileTileCacheLimit'
        QtMocHelpers::SlotData<void(quint64)>(128, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 129 },
        }}),
        // Slot 'creatingTilesStart'
        QtMocHelpers::SlotData<void(TileCreator *, const QString &, const QString &)>(130, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 131, 132 }, { QMetaType::QString, 43 }, { QMetaType::QString, 133 },
        }}),
        // Slot 'reloadMap'
        QtMocHelpers::SlotData<void()>(134, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadRegion'
        QtMocHelpers::SlotData<void(QList<TileCoordsPyramid> const &)>(135, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 136, 4 },
        }}),
        // Slot 'notifyMouseClick'
        QtMocHelpers::SlotData<void(int, int)>(137, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 138 }, { QMetaType::Int, 139 },
        }}),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<void(const QRect &)>(140, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 141, 142 },
        }}),
        // Slot 'setInputEnabled'
        QtMocHelpers::SlotData<void(bool)>(143, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'textureLayer'
        QtMocHelpers::SlotData<TextureLayer *() const>(144, 4, QMC::AccessPublic, 0x80000000 | 145),
        // Slot 'vectorTileLayer'
        QtMocHelpers::SlotData<VectorTileLayer *() const>(146, 4, QMC::AccessPublic, 0x80000000 | 147),
        // Slot 'updateMapTheme'
        QtMocHelpers::SlotData<void()>(148, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSystemBackgroundAttribute'
        QtMocHelpers::SlotData<void()>(149, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'zoom'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'mapThemeId'
        QtMocHelpers::PropertyData<QString>(150, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'projection'
        QtMocHelpers::PropertyData<int>(80, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'longitude'
        QtMocHelpers::PropertyData<qreal>(151, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'latitude'
        QtMocHelpers::PropertyData<qreal>(152, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'showOverviewMap'
        QtMocHelpers::PropertyData<bool>(153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showScaleBar'
        QtMocHelpers::PropertyData<bool>(154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showCompass'
        QtMocHelpers::PropertyData<bool>(155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showGrid'
        QtMocHelpers::PropertyData<bool>(156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showClouds'
        QtMocHelpers::PropertyData<bool>(157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showSunShading'
        QtMocHelpers::PropertyData<bool>(158, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showCityLights'
        QtMocHelpers::PropertyData<bool>(159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isLockedToSubSolarPoint'
        QtMocHelpers::PropertyData<bool>(160, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isSubSolarPointIconVisible'
        QtMocHelpers::PropertyData<bool>(161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'showAtmosphere'
        QtMocHelpers::PropertyData<bool>(162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showCrosshairs'
        QtMocHelpers::PropertyData<bool>(163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showPlaces'
        QtMocHelpers::PropertyData<bool>(164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showCities'
        QtMocHelpers::PropertyData<bool>(165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showTerrain'
        QtMocHelpers::PropertyData<bool>(166, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showOtherPlaces'
        QtMocHelpers::PropertyData<bool>(167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showRelief'
        QtMocHelpers::PropertyData<bool>(168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showIceLayer'
        QtMocHelpers::PropertyData<bool>(169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showBorders'
        QtMocHelpers::PropertyData<bool>(170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showRivers'
        QtMocHelpers::PropertyData<bool>(171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showLakes'
        QtMocHelpers::PropertyData<bool>(172, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'viewContext'
        QtMocHelpers::PropertyData<ViewContext>(123, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'renderStatus'
        QtMocHelpers::PropertyData<RenderStatus>(173, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'volatileTileCacheLimit'
        QtMocHelpers::PropertyData<quint64>(174, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MarbleWidget, qt_meta_tag_ZN6Marble12MarbleWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::MarbleWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12MarbleWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12MarbleWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble12MarbleWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->distanceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->tileLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->viewContextChanged((*reinterpret_cast<std::add_pointer_t<ViewContext>>(_a[1]))); break;
        case 4: _t->themeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->projectionChanged((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 6: _t->mouseMoveGeoPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->mouseClickGeoPosition((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates::Unit>>(_a[3]))); break;
        case 8: _t->framesPerSecond((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 9: _t->regionSelected((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonBox>>(_a[1]))); break;
        case 10: _t->pluginSettingsChanged(); break;
        case 11: _t->renderPluginInitialized((*reinterpret_cast<std::add_pointer_t<RenderPlugin*>>(_a[1]))); break;
        case 12: _t->visibleLatLonAltBoxChanged((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonAltBox>>(_a[1]))); break;
        case 13: _t->renderStatusChanged((*reinterpret_cast<std::add_pointer_t<RenderStatus>>(_a[1]))); break;
        case 14: _t->renderStateChanged((*reinterpret_cast<std::add_pointer_t<RenderState>>(_a[1]))); break;
        case 15: _t->highlightedPlacemarksChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates::Unit>>(_a[3]))); break;
        case 16: _t->propertyValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->setRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 19: _t->setZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 21: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->zoomViewBy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 23: _t->zoomViewBy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 25: _t->zoomIn(); break;
        case 26: _t->zoomOut((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 27: _t->zoomOut(); break;
        case 28: _t->setDistance((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 29: _t->rotateBy((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[3]))); break;
        case 30: _t->rotateBy((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 31: _t->centerOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 32: _t->centerOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 33: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 34: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 35: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonBox>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonBox>>(_a[1]))); break;
        case 37: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 38: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark>>(_a[1]))); break;
        case 39: _t->setCenterLatitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 40: _t->setCenterLatitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 41: _t->setCenterLongitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 42: _t->setCenterLongitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 43: _t->setHeading((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 44: _t->moveLeft((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 45: _t->moveLeft(); break;
        case 46: _t->moveRight((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 47: _t->moveRight(); break;
        case 48: _t->moveUp((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 49: _t->moveUp(); break;
        case 50: _t->moveDown((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 51: _t->moveDown(); break;
        case 52: _t->goHome((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 53: _t->goHome(); break;
        case 54: _t->flyTo((*reinterpret_cast<std::add_pointer_t<GeoDataLookAt>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 55: _t->flyTo((*reinterpret_cast<std::add_pointer_t<GeoDataLookAt>>(_a[1]))); break;
        case 56: _t->setProjection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 57: _t->setProjection((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 58: _t->setMapThemeId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 59: _t->setPropertyValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 60: _t->setShowOverviewMap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->setShowScaleBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->setShowCompass((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->setShowClouds((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: _t->setShowSunShading((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 65: _t->setShowCityLights((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 66: _t->setLockToSubSolarPoint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 67: _t->setSubSolarPointIconVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 68: _t->setShowAtmosphere((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 69: _t->setShowCrosshairs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 70: _t->setShowGrid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 71: _t->setShowPlaces((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 72: _t->setShowCities((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 73: _t->setShowTerrain((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: _t->setShowOtherPlaces((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 75: _t->setShowRelief((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 76: _t->setShowIceLayer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 77: _t->setShowBorders((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 78: _t->setShowRivers((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 79: _t->setShowLakes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 80: _t->setShowFrameRate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 81: _t->setShowBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 82: _t->setShowTileId((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 83: _t->setShowRuntimeTrace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 84: { bool _r = _t->showRuntimeTrace();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 85: _t->setShowDebugPolygons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 86: { bool _r = _t->showDebugPolygons();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 87: _t->setShowDebugBatchRender((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 88: { bool _r = _t->showDebugBatchRender();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 89: _t->setShowDebugPlacemarks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 90: { bool _r = _t->showDebugPlacemarks();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 91: _t->setDebugLevelTags((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 92: { bool _r = _t->debugLevelTags();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 93: _t->setLevelToDebug((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 94: { int _r = _t->levelToDebug();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 95: _t->setMapQualityForViewContext((*reinterpret_cast<std::add_pointer_t<MapQuality>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ViewContext>>(_a[2]))); break;
        case 96: _t->setViewContext((*reinterpret_cast<std::add_pointer_t<ViewContext>>(_a[1]))); break;
        case 97: _t->setAnimationsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 98: _t->clearVolatileTileCache(); break;
        case 99: _t->setVolatileTileCacheLimit((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 100: _t->creatingTilesStart((*reinterpret_cast<std::add_pointer_t<TileCreator*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 101: _t->reloadMap(); break;
        case 102: _t->downloadRegion((*reinterpret_cast<std::add_pointer_t<QList<TileCoordsPyramid>>>(_a[1]))); break;
        case 103: _t->notifyMouseClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 104: _t->setSelection((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 105: _t->setInputEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 106: { TextureLayer* _r = _t->textureLayer();
            if (_a[0]) *reinterpret_cast<TextureLayer**>(_a[0]) = std::move(_r); }  break;
        case 107: { VectorTileLayer* _r = _t->vectorTileLayer();
            if (_a[0]) *reinterpret_cast<VectorTileLayer**>(_a[0]) = std::move(_r); }  break;
        case 108: _t->d->updateMapTheme(); break;
        case 109: _t->d->updateSystemBackgroundAttribute(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(int )>(_a, &MarbleWidget::zoomChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const QString & )>(_a, &MarbleWidget::distanceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(int )>(_a, &MarbleWidget::tileLevelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(ViewContext )>(_a, &MarbleWidget::viewContextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const QString & )>(_a, &MarbleWidget::themeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(Projection )>(_a, &MarbleWidget::projectionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const QString & )>(_a, &MarbleWidget::mouseMoveGeoPosition, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(qreal , qreal , GeoDataCoordinates::Unit )>(_a, &MarbleWidget::mouseClickGeoPosition, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(qreal )>(_a, &MarbleWidget::framesPerSecond, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const GeoDataLatLonBox & )>(_a, &MarbleWidget::regionSelected, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)()>(_a, &MarbleWidget::pluginSettingsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(RenderPlugin * )>(_a, &MarbleWidget::renderPluginInitialized, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const GeoDataLatLonAltBox & )>(_a, &MarbleWidget::visibleLatLonAltBoxChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(RenderStatus )>(_a, &MarbleWidget::renderStatusChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const RenderState & )>(_a, &MarbleWidget::renderStateChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(qreal , qreal , GeoDataCoordinates::Unit )>(_a, &MarbleWidget::highlightedPlacemarksChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleWidget::*)(const QString & , bool )>(_a, &MarbleWidget::propertyValueChanged, 16))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->zoom(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->mapThemeId(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->projection(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->centerLongitude(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->centerLatitude(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showOverviewMap(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showScaleBar(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->showCompass(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->showGrid(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->showClouds(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->showSunShading(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->showCityLights(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isLockedToSubSolarPoint(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isSubSolarPointIconVisible(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->showAtmosphere(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->showCrosshairs(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->showPlaces(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->showCities(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->showTerrain(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->showOtherPlaces(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->showRelief(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->showIceLayer(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->showBorders(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->showRivers(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->showLakes(); break;
        case 25: *reinterpret_cast<ViewContext*>(_v) = _t->viewContext(); break;
        case 26: *reinterpret_cast<RenderStatus*>(_v) = _t->renderStatus(); break;
        case 27: *reinterpret_cast<quint64*>(_v) = _t->volatileTileCacheLimit(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setZoom(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setMapThemeId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setProjection(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setCenterLongitude(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setCenterLatitude(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setShowOverviewMap(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setShowScaleBar(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setShowCompass(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setShowGrid(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setShowClouds(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setShowSunShading(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setShowCityLights(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setLockToSubSolarPoint(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setSubSolarPointIconVisible(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setShowAtmosphere(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setShowCrosshairs(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setShowPlaces(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setShowCities(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setShowTerrain(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setShowOtherPlaces(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setShowRelief(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setShowIceLayer(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setShowBorders(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setShowRivers(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setShowLakes(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setViewContext(*reinterpret_cast<ViewContext*>(_v)); break;
        case 27: _t->setVolatileTileCacheLimit(*reinterpret_cast<quint64*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::MarbleWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12MarbleWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::MarbleWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 110)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 110;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 110)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 110;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void Marble::MarbleWidget::zoomChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::MarbleWidget::distanceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::MarbleWidget::tileLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::MarbleWidget::viewContextChanged(ViewContext _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::MarbleWidget::themeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::MarbleWidget::projectionChanged(Projection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Marble::MarbleWidget::mouseMoveGeoPosition(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::MarbleWidget::mouseClickGeoPosition(qreal _t1, qreal _t2, GeoDataCoordinates::Unit _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void Marble::MarbleWidget::framesPerSecond(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Marble::MarbleWidget::regionSelected(const GeoDataLatLonBox & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Marble::MarbleWidget::pluginSettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Marble::MarbleWidget::renderPluginInitialized(RenderPlugin * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Marble::MarbleWidget::visibleLatLonAltBoxChanged(const GeoDataLatLonAltBox & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Marble::MarbleWidget::renderStatusChanged(RenderStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Marble::MarbleWidget::renderStateChanged(const RenderState & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Marble::MarbleWidget::highlightedPlacemarksChanged(qreal _t1, qreal _t2, GeoDataCoordinates::Unit _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void Marble::MarbleWidget::propertyValueChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}
QT_WARNING_POP
