/****************************************************************************
** Meta object code from reading C++ file 'GeoItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.1/src/lib/marble/declarative/GeoItem.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GeoItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble7GeoItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::GeoItem::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble7GeoItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::GeoItem",
        "longitudeChanged",
        "",
        "latitudeChanged",
        "altitudeChanged",
        "mapChanged",
        "MarbleQuickItem*",
        "map",
        "observableChanged",
        "observable",
        "visObservableChanged",
        "visible",
        "readonlyXChanged",
        "x",
        "readonlyYChanged",
        "y",
        "moveToScreenCoordinates",
        "Marble::MarbleQuickItem*",
        "longitude",
        "latitude",
        "altitude"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'longitudeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'latitudeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'altitudeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapChanged'
        QtMocHelpers::SignalData<void(MarbleQuickItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'observableChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'visObservableChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'readonlyXChanged'
        QtMocHelpers::SignalData<void(qreal)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 13 },
        }}),
        // Signal 'readonlyYChanged'
        QtMocHelpers::SignalData<void(qreal)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 15 },
        }}),
        // Method 'moveToScreenCoordinates'
        QtMocHelpers::MethodData<bool(qreal, qreal)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QReal, 13 }, { QMetaType::QReal, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'map'
        QtMocHelpers::PropertyData<Marble::MarbleQuickItem*>(7, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'longitude'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'latitude'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'altitude'
        QtMocHelpers::PropertyData<qreal>(20, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'observable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags, 6),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeoItem, qt_meta_tag_ZN6Marble7GeoItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::GeoItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble7GeoItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble7GeoItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble7GeoItemE_t>.metaTypes,
    nullptr
} };

void Marble::GeoItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeoItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->longitudeChanged(); break;
        case 1: _t->latitudeChanged(); break;
        case 2: _t->altitudeChanged(); break;
        case 3: _t->mapChanged((*reinterpret_cast<std::add_pointer_t<MarbleQuickItem*>>(_a[1]))); break;
        case 4: _t->observableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->visObservableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->readonlyXChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->readonlyYChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 8: { bool _r = _t->moveToScreenCoordinates((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)()>(_a, &GeoItem::longitudeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)()>(_a, &GeoItem::latitudeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)()>(_a, &GeoItem::altitudeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)(MarbleQuickItem * )>(_a, &GeoItem::mapChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)(bool )>(_a, &GeoItem::observableChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)(bool )>(_a, &GeoItem::visObservableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)(qreal )>(_a, &GeoItem::readonlyXChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoItem::*)(qreal )>(_a, &GeoItem::readonlyYChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Marble::MarbleQuickItem**>(_v) = _t->map(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->longitude(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->latitude(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->altitude(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->observable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->visObservable(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->readonlyX(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->readonlyY(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMap(*reinterpret_cast<Marble::MarbleQuickItem**>(_v)); break;
        case 1: _t->setLongitude(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setLatitude(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setAltitude(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setVisObservable(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::GeoItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::GeoItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble7GeoItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Marble::GeoItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Marble::GeoItem::longitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::GeoItem::latitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::GeoItem::altitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::GeoItem::mapChanged(MarbleQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::GeoItem::observableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::GeoItem::visObservableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Marble::GeoItem::readonlyXChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::GeoItem::readonlyYChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
