/********************************************************************************
** Form generated from reading UI file 'MapViewWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAPVIEWWIDGET_H
#define UI_MAPVIEWWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MapViewWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *toolBarLayout;
    QLabel *projectionLabel_2;
    QComboBox *projectionComboBox;
    QFrame *line;
    QLabel *celestialBodyLabel;
    QComboBox *celestialBodyComboBox;
    QSpacerItem *spacer;
    QLabel *mapThemeLabel;
    QListView *marbleThemeSelectView;
    QComboBox *mapThemeComboBox;

    void setupUi(QWidget *MapViewWidget)
    {
        if (MapViewWidget->objectName().isEmpty())
            MapViewWidget->setObjectName("MapViewWidget");
        MapViewWidget->resize(251, 426);
        verticalLayout = new QVBoxLayout(MapViewWidget);
        verticalLayout->setObjectName("verticalLayout");
        toolBarLayout = new QHBoxLayout();
        toolBarLayout->setSpacing(0);
        toolBarLayout->setObjectName("toolBarLayout");

        verticalLayout->addLayout(toolBarLayout);

        projectionLabel_2 = new QLabel(MapViewWidget);
        projectionLabel_2->setObjectName("projectionLabel_2");

        verticalLayout->addWidget(projectionLabel_2);

        projectionComboBox = new QComboBox(MapViewWidget);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/map-globe.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        projectionComboBox->addItem(icon, QString());
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/map-flat.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        projectionComboBox->addItem(icon1, QString());
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/map-mercator.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        projectionComboBox->addItem(icon2, QString());
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/icons/map-gnomonic.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        projectionComboBox->addItem(icon3, QString());
        projectionComboBox->addItem(icon, QString());
        projectionComboBox->addItem(icon, QString());
        projectionComboBox->addItem(icon, QString());
        projectionComboBox->addItem(icon, QString());
        projectionComboBox->setObjectName("projectionComboBox");
        projectionComboBox->setEnabled(false);

        verticalLayout->addWidget(projectionComboBox);

        line = new QFrame(MapViewWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        celestialBodyLabel = new QLabel(MapViewWidget);
        celestialBodyLabel->setObjectName("celestialBodyLabel");
        celestialBodyLabel->setEnabled(true);

        verticalLayout->addWidget(celestialBodyLabel);

        celestialBodyComboBox = new QComboBox(MapViewWidget);
        celestialBodyComboBox->setObjectName("celestialBodyComboBox");
        celestialBodyComboBox->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(celestialBodyComboBox->sizePolicy().hasHeightForWidth());
        celestialBodyComboBox->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(celestialBodyComboBox);

        spacer = new QSpacerItem(164, 7, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(spacer);

        mapThemeLabel = new QLabel(MapViewWidget);
        mapThemeLabel->setObjectName("mapThemeLabel");

        verticalLayout->addWidget(mapThemeLabel);

        marbleThemeSelectView = new QListView(MapViewWidget);
        marbleThemeSelectView->setObjectName("marbleThemeSelectView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(marbleThemeSelectView->sizePolicy().hasHeightForWidth());
        marbleThemeSelectView->setSizePolicy(sizePolicy1);
        marbleThemeSelectView->setMinimumSize(QSize(0, 140));
        marbleThemeSelectView->setContextMenuPolicy(Qt::CustomContextMenu);
        marbleThemeSelectView->setAutoFillBackground(true);

        verticalLayout->addWidget(marbleThemeSelectView);

        mapThemeComboBox = new QComboBox(MapViewWidget);
        mapThemeComboBox->setObjectName("mapThemeComboBox");

        verticalLayout->addWidget(mapThemeComboBox);

#if QT_CONFIG(shortcut)
        projectionLabel_2->setBuddy(projectionComboBox);
        celestialBodyLabel->setBuddy(projectionComboBox);
        mapThemeLabel->setBuddy(marbleThemeSelectView);
#endif // QT_CONFIG(shortcut)

        retranslateUi(MapViewWidget);

        QMetaObject::connectSlotsByName(MapViewWidget);
    } // setupUi

    void retranslateUi(QWidget *MapViewWidget)
    {
        MapViewWidget->setWindowTitle(QCoreApplication::translate("MapViewWidget", "Map View", nullptr));
        projectionLabel_2->setText(QCoreApplication::translate("MapViewWidget", "&Projection", nullptr));
        projectionComboBox->setItemText(0, QCoreApplication::translate("MapViewWidget", "Globe", nullptr));
        projectionComboBox->setItemText(1, QCoreApplication::translate("MapViewWidget", "Flat Map", nullptr));
        projectionComboBox->setItemText(2, QCoreApplication::translate("MapViewWidget", "Mercator", nullptr));
        projectionComboBox->setItemText(3, QCoreApplication::translate("MapViewWidget", "Gnomonic", nullptr));
        projectionComboBox->setItemText(4, QCoreApplication::translate("MapViewWidget", "Stereographic", nullptr));
        projectionComboBox->setItemText(5, QCoreApplication::translate("MapViewWidget", "Lambert Azimuthal Equal Area", nullptr));
        projectionComboBox->setItemText(6, QCoreApplication::translate("MapViewWidget", "Azimuthal Equidistant", nullptr));
        projectionComboBox->setItemText(7, QCoreApplication::translate("MapViewWidget", "Vertical Perspective Globe", nullptr));

        celestialBodyLabel->setText(QCoreApplication::translate("MapViewWidget", "&Celestial Body", nullptr));
        mapThemeLabel->setText(QCoreApplication::translate("MapViewWidget", "&Theme", nullptr));
#if QT_CONFIG(whatsthis)
        marbleThemeSelectView->setWhatsThis(QCoreApplication::translate("MapViewWidget", "Here you can choose the preferred map view from different topics.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class MapViewWidget: public Ui_MapViewWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAPVIEWWIDGET_H
