/****************************************************************************
** Meta object code from reading C++ file 'FoursquareItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.1/src/plugins/render/foursquare/FoursquareItem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FoursquareItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble14FoursquareItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::FoursquareItem::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble14FoursquareItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::FoursquareItem",
        "nameChanged",
        "",
        "categoryChanged",
        "addressChanged",
        "cityChanged",
        "countryChanged",
        "usersCountChanged",
        "categoryIconUrlChanged",
        "categoryLargeIconUrlChanged",
        "name",
        "category",
        "address",
        "city",
        "country",
        "usersCount",
        "categoryIconUrl",
        "categoryLargeIconUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoryChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addressChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cityChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countryChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usersCountChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoryIconUrlChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoryLargeIconUrlChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'category'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'city'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'country'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'usersCount'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'categoryIconUrl'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'categoryLargeIconUrl'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FoursquareItem, qt_meta_tag_ZN6Marble14FoursquareItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::FoursquareItem::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractDataPluginItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14FoursquareItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14FoursquareItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble14FoursquareItemE_t>.metaTypes,
    nullptr
} };

void Marble::FoursquareItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FoursquareItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->categoryChanged(); break;
        case 2: _t->addressChanged(); break;
        case 3: _t->cityChanged(); break;
        case 4: _t->countryChanged(); break;
        case 5: _t->usersCountChanged(); break;
        case 6: _t->categoryIconUrlChanged(); break;
        case 7: _t->categoryLargeIconUrlChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::categoryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::addressChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::cityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::countryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::usersCountChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::categoryIconUrlChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FoursquareItem::*)()>(_a, &FoursquareItem::categoryLargeIconUrlChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->category(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->city(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->country(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->usersCount(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->categoryIconUrl(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->categoryLargeIconUrl(); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::FoursquareItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::FoursquareItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14FoursquareItemE_t>.strings))
        return static_cast<void*>(this);
    return AbstractDataPluginItem::qt_metacast(_clname);
}

int Marble::FoursquareItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractDataPluginItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Marble::FoursquareItem::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::FoursquareItem::categoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::FoursquareItem::addressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::FoursquareItem::cityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::FoursquareItem::countryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Marble::FoursquareItem::usersCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Marble::FoursquareItem::categoryIconUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Marble::FoursquareItem::categoryLargeIconUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
