/********************************************************************************
** Form generated from reading UI file 'PhotoConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PHOTOCONFIGWIDGET_H
#define UI_PHOTOCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_PhotoConfigWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *m_itemNumberLabel;
    QSpacerItem *horizontalSpacer;
    QSpinBox *m_itemNumberSpinBox;
    QGroupBox *licenseGroupBox;
    QVBoxLayout *verticalLayout_3;
    QListWidget *m_licenseListWidget;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *PhotoConfigWidget)
    {
        if (PhotoConfigWidget->objectName().isEmpty())
            PhotoConfigWidget->setObjectName("PhotoConfigWidget");
        PhotoConfigWidget->resize(405, 303);
        verticalLayout_2 = new QVBoxLayout(PhotoConfigWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        m_itemNumberLabel = new QLabel(PhotoConfigWidget);
        m_itemNumberLabel->setObjectName("m_itemNumberLabel");

        gridLayout->addWidget(m_itemNumberLabel, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(78, 18, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        m_itemNumberSpinBox = new QSpinBox(PhotoConfigWidget);
        m_itemNumberSpinBox->setObjectName("m_itemNumberSpinBox");

        gridLayout->addWidget(m_itemNumberSpinBox, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        licenseGroupBox = new QGroupBox(PhotoConfigWidget);
        licenseGroupBox->setObjectName("licenseGroupBox");
        licenseGroupBox->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);
        verticalLayout_3 = new QVBoxLayout(licenseGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_licenseListWidget = new QListWidget(licenseGroupBox);
        m_licenseListWidget->setObjectName("m_licenseListWidget");

        verticalLayout_3->addWidget(m_licenseListWidget);


        verticalLayout->addWidget(licenseGroupBox);


        verticalLayout_2->addLayout(verticalLayout);

        m_buttonBox = new QDialogButtonBox(PhotoConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Orientation::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Apply|QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_2->addWidget(m_buttonBox);


        retranslateUi(PhotoConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, PhotoConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, PhotoConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(PhotoConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *PhotoConfigWidget)
    {
        PhotoConfigWidget->setWindowTitle(QCoreApplication::translate("PhotoConfigWidget", "Configure Photo Plugin", nullptr));
        m_itemNumberLabel->setText(QCoreApplication::translate("PhotoConfigWidget", "Number of items on the screen", nullptr));
        licenseGroupBox->setTitle(QCoreApplication::translate("PhotoConfigWidget", "License", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PhotoConfigWidget: public Ui_PhotoConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PHOTOCONFIGWIDGET_H
