/****************************************************************************
** Meta object code from reading C++ file 'NewstuffModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/NewstuffModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'NewstuffModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble13NewstuffModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::NewstuffModel::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble13NewstuffModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::NewstuffModel",
        "countChanged",
        "",
        "providerChanged",
        "targetDirectoryChanged",
        "registryFileChanged",
        "installationProgressed",
        "newstuffindex",
        "progress",
        "installationFinished",
        "installationFailed",
        "error",
        "uninstallationFinished",
        "install",
        "index",
        "uninstall",
        "cancel",
        "updateProgress",
        "bytesReceived",
        "bytesTotal",
        "retrieveData",
        "mapInstalled",
        "exitStatus",
        "mapUninstalled",
        "contentsListed",
        "handleProviderData",
        "QNetworkReply*",
        "count",
        "provider",
        "targetDirectory",
        "registryFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'providerChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetDirectoryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'registryFileChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'installationProgressed'
        QtMocHelpers::SignalData<void(int, qreal)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QReal, 8 },
        }}),
        // Signal 'installationFinished'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'installationFailed'
        QtMocHelpers::SignalData<void(int, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'uninstallationFinished'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'install'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'updateProgress'
        QtMocHelpers::SlotData<void(qint64, qint64)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 18 }, { QMetaType::LongLong, 19 },
        }}),
        // Slot 'retrieveData'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mapInstalled'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'mapUninstalled'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contentsListed'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'handleProviderData'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'provider'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'targetDirectory'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'registryFile'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NewstuffModel, qt_meta_tag_ZN6Marble13NewstuffModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::NewstuffModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13NewstuffModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13NewstuffModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble13NewstuffModelE_t>.metaTypes,
    nullptr
} };

void Marble::NewstuffModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NewstuffModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->providerChanged(); break;
        case 2: _t->targetDirectoryChanged(); break;
        case 3: _t->registryFileChanged(); break;
        case 4: _t->installationProgressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 5: _t->installationFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->installationFailed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->uninstallationFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->install((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->uninstall((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->cancel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->updateProgress((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 12: _t->retrieveData(); break;
        case 13: _t->mapInstalled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->mapUninstalled(); break;
        case 15: _t->contentsListed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->d->handleProviderData((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)()>(_a, &NewstuffModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)()>(_a, &NewstuffModel::providerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)()>(_a, &NewstuffModel::targetDirectoryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)()>(_a, &NewstuffModel::registryFileChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)(int , qreal )>(_a, &NewstuffModel::installationProgressed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)(int )>(_a, &NewstuffModel::installationFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)(int , const QString & )>(_a, &NewstuffModel::installationFailed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NewstuffModel::*)(int )>(_a, &NewstuffModel::uninstallationFinished, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->provider(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->targetDirectory(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->registryFile(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setProvider(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setTargetDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setRegistryFile(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::NewstuffModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::NewstuffModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13NewstuffModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int Marble::NewstuffModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Marble::NewstuffModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::NewstuffModel::providerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::NewstuffModel::targetDirectoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::NewstuffModel::registryFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::NewstuffModel::installationProgressed(int _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Marble::NewstuffModel::installationFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Marble::NewstuffModel::installationFailed(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Marble::NewstuffModel::uninstallationFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
