// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: fileformat.proto
// Protobuf C++ Version: 7.35.0

#ifndef fileformat_2eproto_2epb_2eh
#define fileformat_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035000
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_fileformat_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_fileformat_2eproto {
  static const ::uint32_t offsets[];
};
namespace OSMPBF {
class Blob;
struct BlobGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern BlobGlobalsTypeInternal Blob_globals_;
extern const ::google::protobuf::internal::ClassDataLite Blob_class_data_;
#else
extern const BlobGlobalsTypeInternal Blob_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class BlobHeader;
struct BlobHeaderGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern BlobHeaderGlobalsTypeInternal BlobHeader_globals_;
extern const ::google::protobuf::internal::ClassDataLite BlobHeader_class_data_;
#else
extern const BlobHeaderGlobalsTypeInternal BlobHeader_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
}  // namespace OSMPBF
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace OSMPBF {

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED BlobHeader final : public ::google::protobuf::MessageLite
/* @@protoc_insertion_point(class_definition:OSMPBF.BlobHeader) */ {
 public:
  inline BlobHeader() : BlobHeader(nullptr) {}
  ~BlobHeader() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(BlobHeader* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(BlobHeader));
  }
#endif

  template <typename = void>
  explicit constexpr BlobHeader(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline BlobHeader(const BlobHeader& from) : BlobHeader(nullptr, from) {}
  inline BlobHeader(BlobHeader&& from) noexcept : BlobHeader(nullptr, ::std::move(from)) {}
  inline BlobHeader& operator=(const BlobHeader& from) {
    CopyFrom(from);
    return *this;
  }
  inline BlobHeader& operator=(BlobHeader&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::std::string& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString);
  }
  [[nodiscard]] inline ::std::string* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::std::string>();
  }

  [[nodiscard]] static const BlobHeader& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<BlobHeader>(&BlobHeader_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(BlobHeader& a, BlobHeader& b) { a.Swap(&b); }
  inline void Swap(BlobHeader* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(BlobHeader* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] BlobHeader* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::MessageLite::DefaultConstruct<BlobHeader>(arena);
  }
  void CopyFrom(const BlobHeader& from);
  void MergeFrom(const BlobHeader& from) { BlobHeader::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return IsInitializedImpl(*this);
  }

  private:
  static bool IsInitializedImpl(const MessageLite& msg);

  public:
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(BlobHeader* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "OSMPBF.BlobHeader"; }

  explicit BlobHeader(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  BlobHeader(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const BlobHeader& from);
  BlobHeader(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, BlobHeader&& from) noexcept
      : BlobHeader(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kTypeFieldNumber = 1,
    kIndexdataFieldNumber = 2,
    kDatasizeFieldNumber = 3,
  };
  // required string type = 1;
  [[nodiscard]] bool has_type()
      const;
  void clear_type() ;
  [[nodiscard]] const ::std::string& type() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_type(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_type();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_type();
  void set_allocated_type(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_type() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_type(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_type();

  public:
  // optional bytes indexdata = 2;
  [[nodiscard]] bool has_indexdata()
      const;
  void clear_indexdata() ;
  [[nodiscard]] const ::std::string& indexdata() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_indexdata(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_indexdata();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_indexdata();
  void set_allocated_indexdata(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_indexdata() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_indexdata(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_indexdata();

  public:
  // required int32 datasize = 3;
  [[nodiscard]] bool has_datasize()
      const;
  void clear_datasize() ;
  [[nodiscard]] ::int32_t datasize() const;
  void set_datasize(::int32_t value);

  private:
  ::int32_t _internal_datasize() const;
  void _internal_set_datasize(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:OSMPBF.BlobHeader)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 3,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const BlobHeader& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr type_;
    ::google::protobuf::internal::ArenaStringPtr indexdata_;
    ::int32_t datasize_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_fileformat_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Blob final : public ::google::protobuf::MessageLite
/* @@protoc_insertion_point(class_definition:OSMPBF.Blob) */ {
 public:
  inline Blob() : Blob(nullptr) {}
  ~Blob() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Blob* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Blob));
  }
#endif

  template <typename = void>
  explicit constexpr Blob(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Blob(const Blob& from) : Blob(nullptr, from) {}
  inline Blob(Blob&& from) noexcept : Blob(nullptr, ::std::move(from)) {}
  inline Blob& operator=(const Blob& from) {
    CopyFrom(from);
    return *this;
  }
  inline Blob& operator=(Blob&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::std::string& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString);
  }
  [[nodiscard]] inline ::std::string* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::std::string>();
  }

  [[nodiscard]] static const Blob& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Blob>(&Blob_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(Blob& a, Blob& b) { a.Swap(&b); }
  inline void Swap(Blob* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Blob* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Blob* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::MessageLite::DefaultConstruct<Blob>(arena);
  }
  void CopyFrom(const Blob& from);
  void MergeFrom(const Blob& from) { Blob::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Blob* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "OSMPBF.Blob"; }

  explicit Blob(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Blob(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Blob& from);
  Blob(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Blob&& from) noexcept
      : Blob(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kRawFieldNumber = 1,
    kZlibDataFieldNumber = 3,
    kLzmaDataFieldNumber = 4,
    kOBSOLETEBzip2DataFieldNumber = 5,
    kRawSizeFieldNumber = 2,
  };
  // optional bytes raw = 1;
  [[nodiscard]] bool has_raw()
      const;
  void clear_raw() ;
  [[nodiscard]] const ::std::string& raw() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_raw(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_raw();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_raw();
  void set_allocated_raw(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_raw() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_raw(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_raw();

  public:
  // optional bytes zlib_data = 3;
  [[nodiscard]] bool has_zlib_data()
      const;
  void clear_zlib_data() ;
  [[nodiscard]] const ::std::string& zlib_data() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_zlib_data(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_zlib_data();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_zlib_data();
  void set_allocated_zlib_data(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_zlib_data() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_zlib_data(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_zlib_data();

  public:
  // optional bytes lzma_data = 4;
  [[nodiscard]] bool has_lzma_data()
      const;
  void clear_lzma_data() ;
  [[nodiscard]] const ::std::string& lzma_data() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_lzma_data(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_lzma_data();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_lzma_data();
  void set_allocated_lzma_data(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_lzma_data() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_lzma_data(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_lzma_data();

  public:
  // optional bytes OBSOLETE_bzip2_data = 5 [deprecated = true];
  [[nodiscard]] [[deprecated]]  bool has_obsolete_bzip2_data()
      const;
  [[deprecated]]  void clear_obsolete_bzip2_data() ;
  [[nodiscard]] [[deprecated]] const ::std::string& obsolete_bzip2_data() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  [[deprecated]] void set_obsolete_bzip2_data(Arg_&& arg, Args_... args);
  [[deprecated]] ::std::string* PROTOBUF_NONNULL mutable_obsolete_bzip2_data();
  [[deprecated]] [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_obsolete_bzip2_data();
  [[deprecated]] void set_allocated_obsolete_bzip2_data(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_obsolete_bzip2_data() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_obsolete_bzip2_data(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_obsolete_bzip2_data();

  public:
  // optional int32 raw_size = 2;
  [[nodiscard]] bool has_raw_size()
      const;
  void clear_raw_size() ;
  [[nodiscard]] ::int32_t raw_size() const;
  void set_raw_size(::int32_t value);

  private:
  ::int32_t _internal_raw_size() const;
  void _internal_set_raw_size(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:OSMPBF.Blob)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 5,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Blob& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr raw_;
    ::google::protobuf::internal::ArenaStringPtr zlib_data_;
    ::google::protobuf::internal::ArenaStringPtr lzma_data_;
    ::google::protobuf::internal::ArenaStringPtr obsolete_bzip2_data_;
    ::int32_t raw_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_fileformat_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// Blob

// optional bytes raw = 1;
inline bool Blob::has_raw() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void Blob::clear_raw() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.raw_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& Blob::raw() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:OSMPBF.Blob.raw)
  return _internal_raw();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Blob::set_raw(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.raw_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:OSMPBF.Blob.raw)
}
inline ::std::string* PROTOBUF_NONNULL Blob::mutable_raw()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_raw();
  // @@protoc_insertion_point(field_mutable:OSMPBF.Blob.raw)
  return _s;
}
inline const ::std::string& Blob::_internal_raw() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.raw_.Get();
}
inline void Blob::_internal_set_raw(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.raw_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Blob::_internal_mutable_raw() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.raw_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Blob::release_raw() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:OSMPBF.Blob.raw)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.raw_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.raw_.Set("", GetArena());
  }
  return released;
}
inline void Blob::set_allocated_raw(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.raw_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.raw_.IsDefault()) {
    _impl_.raw_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:OSMPBF.Blob.raw)
}

// optional int32 raw_size = 2;
inline bool Blob::has_raw_size() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  return value;
}
inline void Blob::clear_raw_size() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.raw_size_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline ::int32_t Blob::raw_size() const {
  // @@protoc_insertion_point(field_get:OSMPBF.Blob.raw_size)
  return _internal_raw_size();
}
inline void Blob::set_raw_size(::int32_t value) {
  _internal_set_raw_size(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:OSMPBF.Blob.raw_size)
}
inline ::int32_t Blob::_internal_raw_size() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.raw_size_;
}
inline void Blob::_internal_set_raw_size(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.raw_size_ = value;
}

// optional bytes zlib_data = 3;
inline bool Blob::has_zlib_data() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void Blob::clear_zlib_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.zlib_data_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& Blob::zlib_data() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:OSMPBF.Blob.zlib_data)
  return _internal_zlib_data();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Blob::set_zlib_data(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.zlib_data_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:OSMPBF.Blob.zlib_data)
}
inline ::std::string* PROTOBUF_NONNULL Blob::mutable_zlib_data()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_zlib_data();
  // @@protoc_insertion_point(field_mutable:OSMPBF.Blob.zlib_data)
  return _s;
}
inline const ::std::string& Blob::_internal_zlib_data() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.zlib_data_.Get();
}
inline void Blob::_internal_set_zlib_data(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.zlib_data_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Blob::_internal_mutable_zlib_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.zlib_data_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Blob::release_zlib_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:OSMPBF.Blob.zlib_data)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.zlib_data_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.zlib_data_.Set("", GetArena());
  }
  return released;
}
inline void Blob::set_allocated_zlib_data(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.zlib_data_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.zlib_data_.IsDefault()) {
    _impl_.zlib_data_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:OSMPBF.Blob.zlib_data)
}

// optional bytes lzma_data = 4;
inline bool Blob::has_lzma_data() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void Blob::clear_lzma_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.lzma_data_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline const ::std::string& Blob::lzma_data() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:OSMPBF.Blob.lzma_data)
  return _internal_lzma_data();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Blob::set_lzma_data(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  _impl_.lzma_data_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:OSMPBF.Blob.lzma_data)
}
inline ::std::string* PROTOBUF_NONNULL Blob::mutable_lzma_data()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::std::string* _s = _internal_mutable_lzma_data();
  // @@protoc_insertion_point(field_mutable:OSMPBF.Blob.lzma_data)
  return _s;
}
inline const ::std::string& Blob::_internal_lzma_data() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.lzma_data_.Get();
}
inline void Blob::_internal_set_lzma_data(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.lzma_data_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Blob::_internal_mutable_lzma_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.lzma_data_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Blob::release_lzma_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:OSMPBF.Blob.lzma_data)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000004U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  auto* released = _impl_.lzma_data_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.lzma_data_.Set("", GetArena());
  }
  return released;
}
inline void Blob::set_allocated_lzma_data(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  _impl_.lzma_data_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.lzma_data_.IsDefault()) {
    _impl_.lzma_data_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:OSMPBF.Blob.lzma_data)
}

// optional bytes OBSOLETE_bzip2_data = 5 [deprecated = true];
inline bool Blob::has_obsolete_bzip2_data() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  return value;
}
inline void Blob::clear_obsolete_bzip2_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.obsolete_bzip2_data_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline const ::std::string& Blob::obsolete_bzip2_data() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:OSMPBF.Blob.OBSOLETE_bzip2_data)
  return _internal_obsolete_bzip2_data();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Blob::set_obsolete_bzip2_data(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  _impl_.obsolete_bzip2_data_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:OSMPBF.Blob.OBSOLETE_bzip2_data)
}
inline ::std::string* PROTOBUF_NONNULL Blob::mutable_obsolete_bzip2_data()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::std::string* _s = _internal_mutable_obsolete_bzip2_data();
  // @@protoc_insertion_point(field_mutable:OSMPBF.Blob.OBSOLETE_bzip2_data)
  return _s;
}
inline const ::std::string& Blob::_internal_obsolete_bzip2_data() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.obsolete_bzip2_data_.Get();
}
inline void Blob::_internal_set_obsolete_bzip2_data(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.obsolete_bzip2_data_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Blob::_internal_mutable_obsolete_bzip2_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.obsolete_bzip2_data_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Blob::release_obsolete_bzip2_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:OSMPBF.Blob.OBSOLETE_bzip2_data)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000008U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  auto* released = _impl_.obsolete_bzip2_data_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.obsolete_bzip2_data_.Set("", GetArena());
  }
  return released;
}
inline void Blob::set_allocated_obsolete_bzip2_data(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  _impl_.obsolete_bzip2_data_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.obsolete_bzip2_data_.IsDefault()) {
    _impl_.obsolete_bzip2_data_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:OSMPBF.Blob.OBSOLETE_bzip2_data)
}

// -------------------------------------------------------------------

// BlobHeader

// required string type = 1;
inline bool BlobHeader::has_type() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void BlobHeader::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& BlobHeader::type() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:OSMPBF.BlobHeader.type)
  return _internal_type();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void BlobHeader::set_type(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.type_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:OSMPBF.BlobHeader.type)
}
inline ::std::string* PROTOBUF_NONNULL BlobHeader::mutable_type()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_type();
  // @@protoc_insertion_point(field_mutable:OSMPBF.BlobHeader.type)
  return _s;
}
inline const ::std::string& BlobHeader::_internal_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.type_.Get();
}
inline void BlobHeader::_internal_set_type(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL BlobHeader::_internal_mutable_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.type_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE BlobHeader::release_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:OSMPBF.BlobHeader.type)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.type_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.type_.Set("", GetArena());
  }
  return released;
}
inline void BlobHeader::set_allocated_type(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.type_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.type_.IsDefault()) {
    _impl_.type_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:OSMPBF.BlobHeader.type)
}

// optional bytes indexdata = 2;
inline bool BlobHeader::has_indexdata() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void BlobHeader::clear_indexdata() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.indexdata_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& BlobHeader::indexdata() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:OSMPBF.BlobHeader.indexdata)
  return _internal_indexdata();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void BlobHeader::set_indexdata(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.indexdata_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:OSMPBF.BlobHeader.indexdata)
}
inline ::std::string* PROTOBUF_NONNULL BlobHeader::mutable_indexdata()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_indexdata();
  // @@protoc_insertion_point(field_mutable:OSMPBF.BlobHeader.indexdata)
  return _s;
}
inline const ::std::string& BlobHeader::_internal_indexdata() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.indexdata_.Get();
}
inline void BlobHeader::_internal_set_indexdata(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.indexdata_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL BlobHeader::_internal_mutable_indexdata() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.indexdata_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE BlobHeader::release_indexdata() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:OSMPBF.BlobHeader.indexdata)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.indexdata_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.indexdata_.Set("", GetArena());
  }
  return released;
}
inline void BlobHeader::set_allocated_indexdata(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.indexdata_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.indexdata_.IsDefault()) {
    _impl_.indexdata_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:OSMPBF.BlobHeader.indexdata)
}

// required int32 datasize = 3;
inline bool BlobHeader::has_datasize() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void BlobHeader::clear_datasize() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.datasize_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline ::int32_t BlobHeader::datasize() const {
  // @@protoc_insertion_point(field_get:OSMPBF.BlobHeader.datasize)
  return _internal_datasize();
}
inline void BlobHeader::set_datasize(::int32_t value) {
  _internal_set_datasize(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:OSMPBF.BlobHeader.datasize)
}
inline ::int32_t BlobHeader::_internal_datasize() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.datasize_;
}
inline void BlobHeader::_internal_set_datasize(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.datasize_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace OSMPBF


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // fileformat_2eproto_2epb_2eh
