/****************************************************************************
** Meta object code from reading C++ file 'MarbleModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/MarbleModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MarbleModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble11MarbleModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleModel::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble11MarbleModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleModel",
        "creatingTilesStart",
        "",
        "TileCreator*",
        "name",
        "description",
        "themeChanged",
        "mapTheme",
        "workOfflineChanged",
        "trackedPlacemarkChanged",
        "const GeoDataPlacemark*",
        "placemark",
        "homeChanged",
        "GeoDataCoordinates",
        "newHomePoint",
        "clearPersistentTileCache",
        "setPersistentTileCacheLimit",
        "kiloBytes",
        "setTrackedPlacemark",
        "updateProperty",
        "property",
        "value",
        "assignFillColors",
        "filePath",
        "mapThemeId",
        "workOffline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'creatingTilesStart'
        QtMocHelpers::SignalData<void(TileCreator *, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'workOfflineChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackedPlacemarkChanged'
        QtMocHelpers::SignalData<void(const GeoDataPlacemark *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'homeChanged'
        QtMocHelpers::SignalData<void(const GeoDataCoordinates &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'clearPersistentTileCache'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPersistentTileCacheLimit'
        QtMocHelpers::SlotData<void(quint64)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 17 },
        }}),
        // Slot 'setTrackedPlacemark'
        QtMocHelpers::SlotData<void(const GeoDataPlacemark *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(const QString &, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'assignFillColors'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mapThemeId'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'workOffline'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarbleModel, qt_meta_tag_ZN6Marble11MarbleModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MarbleModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11MarbleModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11MarbleModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble11MarbleModelE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->creatingTilesStart((*reinterpret_cast<std::add_pointer_t<TileCreator*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->themeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->workOfflineChanged(); break;
        case 3: _t->trackedPlacemarkChanged((*reinterpret_cast<std::add_pointer_t<const GeoDataPlacemark*>>(_a[1]))); break;
        case 4: _t->homeChanged((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 5: _t->clearPersistentTileCache(); break;
        case 6: _t->setPersistentTileCacheLimit((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 7: _t->setTrackedPlacemark((*reinterpret_cast<std::add_pointer_t<const GeoDataPlacemark*>>(_a[1]))); break;
        case 8: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->d->assignFillColors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarbleModel::*)(TileCreator * , const QString & , const QString & )>(_a, &MarbleModel::creatingTilesStart, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleModel::*)(const QString & )>(_a, &MarbleModel::themeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleModel::*)()>(_a, &MarbleModel::workOfflineChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleModel::*)(const GeoDataPlacemark * )>(_a, &MarbleModel::trackedPlacemarkChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleModel::*)(const GeoDataCoordinates & )>(_a, &MarbleModel::homeChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->mapThemeId(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->workOffline(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMapThemeId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setWorkOffline(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::MarbleModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11MarbleModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::MarbleModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Marble::MarbleModel::creatingTilesStart(TileCreator * _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Marble::MarbleModel::themeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::MarbleModel::workOfflineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::MarbleModel::trackedPlacemarkChanged(const GeoDataPlacemark * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::MarbleModel::homeChanged(const GeoDataCoordinates & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
