/****************************************************************************
** Meta object code from reading C++ file 'ElevationProfileDataSource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.1/src/plugins/render/elevationprofilefloatitem/ElevationProfileDataSource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ElevationProfileDataSource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::ElevationProfileDataSource::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::ElevationProfileDataSource",
        "sourceCountChanged",
        "",
        "dataUpdated",
        "GeoDataLineString",
        "points",
        "QList<QPointF>",
        "elevationData",
        "requestUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceCountChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataUpdated'
        QtMocHelpers::SignalData<void(const GeoDataLineString &, const QList<QPointF> &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'requestUpdate'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ElevationProfileDataSource, qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::ElevationProfileDataSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t>.metaTypes,
    nullptr
} };

void Marble::ElevationProfileDataSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElevationProfileDataSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceCountChanged(); break;
        case 1: _t->dataUpdated((*reinterpret_cast<std::add_pointer_t<GeoDataLineString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QPointF>>>(_a[2]))); break;
        case 2: _t->requestUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ElevationProfileDataSource::*)()>(_a, &ElevationProfileDataSource::sourceCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElevationProfileDataSource::*)(const GeoDataLineString & , const QList<QPointF> & )>(_a, &ElevationProfileDataSource::dataUpdated, 1))
            return;
    }
}

const QMetaObject *Marble::ElevationProfileDataSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::ElevationProfileDataSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble26ElevationProfileDataSourceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::ElevationProfileDataSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Marble::ElevationProfileDataSource::sourceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::ElevationProfileDataSource::dataUpdated(const GeoDataLineString & _t1, const QList<QPointF> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::ElevationProfileTrackDataSource::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::ElevationProfileTrackDataSource",
        "requestUpdate",
        "",
        "handleObjectAdded",
        "GeoDataObject*",
        "object",
        "handleObjectRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'requestUpdate'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleObjectAdded'
        QtMocHelpers::SlotData<void(GeoDataObject *)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handleObjectRemoved'
        QtMocHelpers::SlotData<void(GeoDataObject *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ElevationProfileTrackDataSource, qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::ElevationProfileTrackDataSource::staticMetaObject = { {
    QMetaObject::SuperData::link<ElevationProfileDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t>.metaTypes,
    nullptr
} };

void Marble::ElevationProfileTrackDataSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElevationProfileTrackDataSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestUpdate(); break;
        case 1: _t->handleObjectAdded((*reinterpret_cast<std::add_pointer_t<GeoDataObject*>>(_a[1]))); break;
        case 2: _t->handleObjectRemoved((*reinterpret_cast<std::add_pointer_t<GeoDataObject*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Marble::ElevationProfileTrackDataSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::ElevationProfileTrackDataSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble31ElevationProfileTrackDataSourceE_t>.strings))
        return static_cast<void*>(this);
    return ElevationProfileDataSource::qt_metacast(_clname);
}

int Marble::ElevationProfileTrackDataSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ElevationProfileDataSource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::ElevationProfileRouteDataSource::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::ElevationProfileRouteDataSource",
        "requestUpdate",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'requestUpdate'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ElevationProfileRouteDataSource, qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::ElevationProfileRouteDataSource::staticMetaObject = { {
    QMetaObject::SuperData::link<ElevationProfileDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t>.metaTypes,
    nullptr
} };

void Marble::ElevationProfileRouteDataSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElevationProfileRouteDataSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestUpdate(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Marble::ElevationProfileRouteDataSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::ElevationProfileRouteDataSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble31ElevationProfileRouteDataSourceE_t>.strings))
        return static_cast<void*>(this);
    return ElevationProfileDataSource::qt_metacast(_clname);
}

int Marble::ElevationProfileRouteDataSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ElevationProfileDataSource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
