/****************************************************************************
** Meta object code from reading C++ file 'MapThemeModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.1/src/lib/marble/declarative/MapThemeModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MapThemeModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MapThemeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MapThemeModel::qt_create_metaobjectdata<qt_meta_tag_ZN13MapThemeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MapThemeModel",
        "QML.Element",
        "auto",
        "mapThemeFilterChanged",
        "",
        "setMapThemeFilter",
        "MapThemeFilters",
        "filters",
        "handleChangedThemes",
        "name",
        "id",
        "indexOf",
        "mapThemeFilter",
        "MapThemeFilter",
        "AnyTheme",
        "Terrestrial",
        "Extraterrestrial",
        "LowZoom",
        "HighZoom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mapThemeFilterChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMapThemeFilter'
        QtMocHelpers::SlotData<void(MapThemeFilters)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'handleChangedThemes'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'name'
        QtMocHelpers::MethodData<QString(const QString &) const>(9, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'indexOf'
        QtMocHelpers::MethodData<int(const QString &) const>(11, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'mapThemeFilter'
        QtMocHelpers::MethodData<MapThemeFilters() const>(12, 4, QMC::AccessPublic, 0x80000000 | 6),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mapThemeFilter'
        QtMocHelpers::PropertyData<MapThemeFilters>(12, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MapThemeFilter'
        QtMocHelpers::EnumData<enum MapThemeFilter>(13, 13, QMC::EnumFlags{}).add({
            {   14, MapThemeFilter::AnyTheme },
            {   15, MapThemeFilter::Terrestrial },
            {   16, MapThemeFilter::Extraterrestrial },
            {   17, MapThemeFilter::LowZoom },
            {   18, MapThemeFilter::HighZoom },
        }),
        // flag 'MapThemeFilters'
        QtMocHelpers::EnumData<MapThemeFilters>(6, 13, QMC::EnumIsFlag).add({
            {   14, MapThemeFilter::AnyTheme },
            {   15, MapThemeFilter::Terrestrial },
            {   16, MapThemeFilter::Extraterrestrial },
            {   17, MapThemeFilter::LowZoom },
            {   18, MapThemeFilter::HighZoom },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MapThemeModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MapThemeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MapThemeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MapThemeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MapThemeModelE_t>.metaTypes,
    nullptr
} };

void MapThemeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MapThemeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mapThemeFilterChanged(); break;
        case 1: _t->setMapThemeFilter((*reinterpret_cast<std::add_pointer_t<MapThemeFilters>>(_a[1]))); break;
        case 2: _t->handleChangedThemes(); break;
        case 3: { QString _r = _t->name((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->indexOf((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { MapThemeFilters _r = _t->mapThemeFilter();
            if (_a[0]) *reinterpret_cast<MapThemeFilters*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MapThemeModel::*)()>(_a, &MapThemeModel::mapThemeFilterChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::assignFlags<MapThemeFilters>(_v, _t->mapThemeFilter()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMapThemeFilter(*reinterpret_cast<MapThemeFilters*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MapThemeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MapThemeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MapThemeModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int MapThemeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void MapThemeModel::mapThemeFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
