/****************************************************************************
** Meta object code from reading C++ file 'RoutingInputWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/routing/RoutingInputWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RoutingInputWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::RoutingInputWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::RoutingInputWidget",
        "searchFinished",
        "",
        "RoutingInputWidget*",
        "removalRequest",
        "activityRequest",
        "mapInputModeEnabled",
        "enabled",
        "targetValidityChanged",
        "targetValid",
        "findPlacemarks",
        "setTargetPosition",
        "GeoDataCoordinates",
        "position",
        "name",
        "abortMapInputRequest",
        "reloadBookmarks",
        "setPlacemarkModel",
        "QAbstractItemModel*",
        "requestActivity",
        "requestRemoval",
        "setMapInputModeEnabled",
        "finishSearch",
        "setInvalid",
        "updatePosition",
        "index",
        "reverseGeocoding",
        "retrieveReverseGeocodingResult",
        "coordinates",
        "GeoDataPlacemark",
        "placemark",
        "setHomePosition",
        "setCurrentLocation",
        "updateCurrentLocationButton",
        "PositionProviderStatus",
        "status",
        "updateCenterButton",
        "hasPosition",
        "setBookmarkPosition",
        "QAction*",
        "bookmark",
        "openTargetSelectionDialog",
        "showMenu"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'searchFinished'
        QtMocHelpers::SignalData<void(RoutingInputWidget *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'removalRequest'
        QtMocHelpers::SignalData<void(RoutingInputWidget *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'activityRequest'
        QtMocHelpers::SignalData<void(RoutingInputWidget *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'mapInputModeEnabled'
        QtMocHelpers::SignalData<void(RoutingInputWidget *, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'targetValidityChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'findPlacemarks'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTargetPosition'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'setTargetPosition'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'abortMapInputRequest'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadBookmarks'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPlacemarkModel'
        QtMocHelpers::SlotData<void(QAbstractItemModel *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'requestActivity'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'requestRemoval'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setMapInputModeEnabled'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'finishSearch'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setInvalid'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePosition'
        QtMocHelpers::SlotData<void(int, const GeoDataCoordinates &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 25 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'reverseGeocoding'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'retrieveReverseGeocodingResult'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &, const GeoDataPlacemark &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setHomePosition'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCurrentLocation'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCurrentLocationButton'
        QtMocHelpers::SlotData<void(PositionProviderStatus)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'updateCenterButton'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'setBookmarkPosition'
        QtMocHelpers::SlotData<void(QAction *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'openTargetSelectionDialog'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RoutingInputWidget, qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::RoutingInputWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::RoutingInputWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RoutingInputWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->searchFinished((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1]))); break;
        case 1: _t->removalRequest((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1]))); break;
        case 2: _t->activityRequest((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1]))); break;
        case 3: _t->mapInputModeEnabled((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->targetValidityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->findPlacemarks(); break;
        case 6: _t->setTargetPosition((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->setTargetPosition((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 8: _t->abortMapInputRequest(); break;
        case 9: _t->reloadBookmarks(); break;
        case 10: _t->setPlacemarkModel((*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[1]))); break;
        case 11: _t->requestActivity(); break;
        case 12: _t->requestRemoval(); break;
        case 13: _t->setMapInputModeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->finishSearch(); break;
        case 15: _t->setInvalid(); break;
        case 16: _t->updatePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[2]))); break;
        case 17: _t->reverseGeocoding(); break;
        case 18: _t->retrieveReverseGeocodingResult((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark>>(_a[2]))); break;
        case 19: _t->setHomePosition(); break;
        case 20: _t->setCurrentLocation(); break;
        case 21: _t->updateCurrentLocationButton((*reinterpret_cast<std::add_pointer_t<PositionProviderStatus>>(_a[1]))); break;
        case 22: _t->updateCenterButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setBookmarkPosition((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 24: _t->openTargetSelectionDialog(); break;
        case 25: _t->showMenu(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< RoutingInputWidget* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< RoutingInputWidget* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< RoutingInputWidget* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< RoutingInputWidget* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RoutingInputWidget::*)(RoutingInputWidget * )>(_a, &RoutingInputWidget::searchFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RoutingInputWidget::*)(RoutingInputWidget * )>(_a, &RoutingInputWidget::removalRequest, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RoutingInputWidget::*)(RoutingInputWidget * )>(_a, &RoutingInputWidget::activityRequest, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RoutingInputWidget::*)(RoutingInputWidget * , bool )>(_a, &RoutingInputWidget::mapInputModeEnabled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RoutingInputWidget::*)(bool )>(_a, &RoutingInputWidget::targetValidityChanged, 4))
            return;
    }
}

const QMetaObject *Marble::RoutingInputWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::RoutingInputWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble18RoutingInputWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::RoutingInputWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void Marble::RoutingInputWidget::searchFinished(RoutingInputWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::RoutingInputWidget::removalRequest(RoutingInputWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::RoutingInputWidget::activityRequest(RoutingInputWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::RoutingInputWidget::mapInputModeEnabled(RoutingInputWidget * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Marble::RoutingInputWidget::targetValidityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
