/****************************************************************************
** Meta object code from reading C++ file 'GeoPolyline.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.1/src/lib/marble/declarative/GeoPolyline.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GeoPolyline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble11GeoPolylineE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::GeoPolyline::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble11GeoPolylineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::GeoPolyline",
        "mapChanged",
        "",
        "MarbleQuickItem*",
        "map",
        "observableChanged",
        "observable",
        "geoCoordinatesChanged",
        "screenCoordinatesChanged",
        "lineColorChanged",
        "QColor",
        "lineColor",
        "lineWidthChanged",
        "lineWidth",
        "tessellateChanged",
        "tessellate",
        "clipScreenCoordinatesChanged",
        "enabled",
        "readonlyXChanged",
        "readonlyYChanged",
        "readonlyWidthChanged",
        "readonlyHeightChanged",
        "x",
        "y",
        "width",
        "height",
        "Marble::MarbleQuickItem*",
        "geoCoordinates",
        "QVariantList",
        "screenCoordinates",
        "clipScreenCoordinates"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mapChanged'
        QtMocHelpers::SignalData<void(MarbleQuickItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'observableChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'geoCoordinatesChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenCoordinatesChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void(qreal)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 13 },
        }}),
        // Signal 'tessellateChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'clipScreenCoordinatesChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'readonlyXChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readonlyYChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readonlyWidthChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readonlyHeightChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags, 8),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags, 9),
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags, 10),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(25, QMetaType::QReal, QMC::DefaultPropertyFlags, 11),
        // property 'map'
        QtMocHelpers::PropertyData<Marble::MarbleQuickItem*>(4, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'geoCoordinates'
        QtMocHelpers::PropertyData<QVariantList>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'screenCoordinates'
        QtMocHelpers::PropertyData<QVariantList>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'observable'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'tessellate'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'lineColor'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'clipScreenCoordinates'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeoPolyline, qt_meta_tag_ZN6Marble11GeoPolylineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::GeoPolyline::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11GeoPolylineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11GeoPolylineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble11GeoPolylineE_t>.metaTypes,
    nullptr
} };

void Marble::GeoPolyline::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeoPolyline *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mapChanged((*reinterpret_cast<std::add_pointer_t<MarbleQuickItem*>>(_a[1]))); break;
        case 1: _t->observableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->geoCoordinatesChanged(); break;
        case 3: _t->screenCoordinatesChanged(); break;
        case 4: _t->lineColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->lineWidthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 6: _t->tessellateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->clipScreenCoordinatesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->readonlyXChanged(); break;
        case 9: _t->readonlyYChanged(); break;
        case 10: _t->readonlyWidthChanged(); break;
        case 11: _t->readonlyHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)(MarbleQuickItem * )>(_a, &GeoPolyline::mapChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)(bool )>(_a, &GeoPolyline::observableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)()>(_a, &GeoPolyline::geoCoordinatesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)()>(_a, &GeoPolyline::screenCoordinatesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)(QColor )>(_a, &GeoPolyline::lineColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)(qreal )>(_a, &GeoPolyline::lineWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)(bool )>(_a, &GeoPolyline::tessellateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)(bool )>(_a, &GeoPolyline::clipScreenCoordinatesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)()>(_a, &GeoPolyline::readonlyXChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)()>(_a, &GeoPolyline::readonlyYChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)()>(_a, &GeoPolyline::readonlyWidthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoPolyline::*)()>(_a, &GeoPolyline::readonlyHeightChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->readonlyX(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->readonlyY(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->readonlyWidth(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->readonlyHeight(); break;
        case 4: *reinterpret_cast<Marble::MarbleQuickItem**>(_v) = _t->map(); break;
        case 5: *reinterpret_cast<QVariantList*>(_v) = _t->geoCoordinates(); break;
        case 6: *reinterpret_cast<QVariantList*>(_v) = _t->screenCoordinates(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->observable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->tessellate(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->lineColor(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->lineWidth(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->clipScreenCoordinates(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setMap(*reinterpret_cast<Marble::MarbleQuickItem**>(_v)); break;
        case 5: _t->setGeoCoordinates(*reinterpret_cast<QVariantList*>(_v)); break;
        case 8: _t->setTessellate(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setLineColor(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setLineWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 11: _t->setClipScreenCoordinates(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::GeoPolyline::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::GeoPolyline::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11GeoPolylineE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Marble::GeoPolyline::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Marble::GeoPolyline::mapChanged(MarbleQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::GeoPolyline::observableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::GeoPolyline::geoCoordinatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::GeoPolyline::screenCoordinatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::GeoPolyline::lineColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::GeoPolyline::lineWidthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Marble::GeoPolyline::tessellateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::GeoPolyline::clipScreenCoordinatesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Marble::GeoPolyline::readonlyXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Marble::GeoPolyline::readonlyYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Marble::GeoPolyline::readonlyWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Marble::GeoPolyline::readonlyHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
