/****************************************************************************
** Meta object code from reading C++ file 'MarbleDBusInterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/MarbleDBusInterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MarbleDBusInterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleDBusInterface::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleDBusInterface",
        "D-Bus Interface",
        "org.kde.marble",
        "mapThemeChanged",
        "",
        "mapTheme",
        "tileLevelChanged",
        "tileLevel",
        "zoomChanged",
        "zoom",
        "centerChanged",
        "QPointF",
        "center",
        "setMapTheme",
        "setZoom",
        "properties",
        "setCenter",
        "setPropertyEnabled",
        "key",
        "enabled",
        "isPropertyEnabled",
        "handleVisibleLatLonAltBoxChange",
        "mapThemes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mapThemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'tileLevelChanged'
        QtMocHelpers::SignalData<void(int)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'centerChanged'
        QtMocHelpers::SignalData<void(const QPointF &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setMapTheme'
        QtMocHelpers::SlotData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'properties'
        QtMocHelpers::SlotData<QStringList() const>(15, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'setCenter'
        QtMocHelpers::SlotData<void(const QPointF &) const>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setPropertyEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'isPropertyEnabled'
        QtMocHelpers::SlotData<bool(const QString &) const>(20, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'handleVisibleLatLonAltBoxChange'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mapTheme'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'mapThemes'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'tileLevel'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'zoom'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'properties'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'center'
        QtMocHelpers::PropertyData<QPointF>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MarbleDBusInterface, qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::MarbleDBusInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleDBusInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleDBusInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mapThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->tileLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->centerChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 4: _t->setMapTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: { QStringList _r = _t->properties();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setCenter((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 8: _t->setPropertyEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: { bool _r = _t->isPropertyEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->handleVisibleLatLonAltBoxChange(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarbleDBusInterface::*)(const QString & )>(_a, &MarbleDBusInterface::mapThemeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleDBusInterface::*)(int )>(_a, &MarbleDBusInterface::tileLevelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleDBusInterface::*)(int )>(_a, &MarbleDBusInterface::zoomChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleDBusInterface::*)(const QPointF & )>(_a, &MarbleDBusInterface::centerChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->mapTheme(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->mapThemes(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->tileLevel(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->zoom(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->properties(); break;
        case 5: *reinterpret_cast<QPointF*>(_v) = _t->center(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMapTheme(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setZoom(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setCenter(*reinterpret_cast<QPointF*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::MarbleDBusInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleDBusInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19MarbleDBusInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Marble::MarbleDBusInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Marble::MarbleDBusInterface::mapThemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::MarbleDBusInterface::tileLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::MarbleDBusInterface::zoomChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::MarbleDBusInterface::centerChanged(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
