/****************************************************************************
** Meta object code from reading C++ file 'MarbleAbstractPresenter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/MarbleAbstractPresenter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MarbleAbstractPresenter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleAbstractPresenter::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleAbstractPresenter",
        "zoomChanged",
        "",
        "zoom",
        "distanceChanged",
        "distanceString",
        "regionSelected",
        "GeoDataLatLonBox",
        "boundingBox",
        "rotateBy",
        "deltaLon",
        "deltaLat",
        "FlyToMode",
        "mode",
        "flyTo",
        "GeoDataLookAt",
        "newLookAt",
        "goHome",
        "setZoom",
        "newZoom",
        "zoomView",
        "zoomViewBy",
        "zoomStep",
        "zoomIn",
        "zoomOut",
        "zoomAtBy",
        "QPoint",
        "pos",
        "setViewContext",
        "ViewContext",
        "viewContext",
        "centerOn",
        "lon",
        "lat",
        "animated",
        "GeoDataCoordinates",
        "point",
        "box",
        "GeoDataPlacemark",
        "placemark",
        "headingOn",
        "heading",
        "setCenterLatitude",
        "setCenterLongitude",
        "setAnimationsEnabled",
        "enabled",
        "setRadius",
        "radius",
        "setDistance",
        "newDistance",
        "setSelection",
        "QRect",
        "region"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'distanceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'regionSelected'
        QtMocHelpers::SignalData<void(const GeoDataLatLonBox &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'rotateBy'
        QtMocHelpers::SlotData<void(const qreal, const qreal, FlyToMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 10 }, { QMetaType::QReal, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'rotateBy'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QReal, 10 }, { QMetaType::QReal, 11 },
        }}),
        // Slot 'flyTo'
        QtMocHelpers::SlotData<void(const GeoDataLookAt &, FlyToMode)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'flyTo'
        QtMocHelpers::SlotData<void(const GeoDataLookAt &)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'goHome'
        QtMocHelpers::SlotData<void(FlyToMode)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'goHome'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(int, FlyToMode)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(int, FlyToMode)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'zoomViewBy'
        QtMocHelpers::SlotData<void(int, FlyToMode)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'zoomViewBy'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void(FlyToMode)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void(FlyToMode)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomAtBy'
        QtMocHelpers::SlotData<void(const QPoint &, int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'setViewContext'
        QtMocHelpers::SlotData<void(ViewContext)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const qreal, const qreal, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 32 }, { QMetaType::QReal, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QReal, 32 }, { QMetaType::QReal, 33 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataLatLonBox &, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 37 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataLatLonBox &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 37 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataPlacemark &, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataPlacemark &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'headingOn'
        QtMocHelpers::SlotData<void(qreal)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 41 },
        }}),
        // Slot 'setCenterLatitude'
        QtMocHelpers::SlotData<void(qreal, FlyToMode)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 33 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setCenterLongitude'
        QtMocHelpers::SlotData<void(qreal, FlyToMode)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 32 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setAnimationsEnabled'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'setRadius'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 47 },
        }}),
        // Slot 'setDistance'
        QtMocHelpers::SlotData<void(qreal)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 49 },
        }}),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<void(const QRect &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarbleAbstractPresenter, qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MarbleAbstractPresenter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleAbstractPresenter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleAbstractPresenter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->distanceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->regionSelected((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonBox>>(_a[1]))); break;
        case 3: _t->rotateBy((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[3]))); break;
        case 4: _t->rotateBy((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 5: _t->flyTo((*reinterpret_cast<std::add_pointer_t<GeoDataLookAt>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 6: _t->flyTo((*reinterpret_cast<std::add_pointer_t<GeoDataLookAt>>(_a[1]))); break;
        case 7: _t->goHome((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 8: _t->goHome(); break;
        case 9: _t->setZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 10: _t->setZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 12: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->zoomViewBy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 14: _t->zoomViewBy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 16: _t->zoomIn(); break;
        case 17: _t->zoomOut((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 18: _t->zoomOut(); break;
        case 19: _t->zoomAtBy((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 20: _t->setViewContext((*reinterpret_cast<std::add_pointer_t<ViewContext>>(_a[1]))); break;
        case 21: _t->centerOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 22: _t->centerOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 23: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 24: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 25: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonBox>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonBox>>(_a[1]))); break;
        case 27: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 28: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark>>(_a[1]))); break;
        case 29: _t->headingOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 30: _t->setCenterLatitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 31: _t->setCenterLongitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[2]))); break;
        case 32: _t->setAnimationsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->setDistance((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 35: _t->setSelection((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarbleAbstractPresenter::*)(int )>(_a, &MarbleAbstractPresenter::zoomChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleAbstractPresenter::*)(const QString & )>(_a, &MarbleAbstractPresenter::distanceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleAbstractPresenter::*)(const GeoDataLatLonBox & )>(_a, &MarbleAbstractPresenter::regionSelected, 2))
            return;
    }
}

const QMetaObject *Marble::MarbleAbstractPresenter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleAbstractPresenter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble23MarbleAbstractPresenterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::MarbleAbstractPresenter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void Marble::MarbleAbstractPresenter::zoomChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::MarbleAbstractPresenter::distanceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::MarbleAbstractPresenter::regionSelected(const GeoDataLatLonBox & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
