/****************************************************************************
** Meta object code from reading C++ file 'EditPlacemarkDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/EditPlacemarkDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'EditPlacemarkDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::EditPlacemarkDialog::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::EditPlacemarkDialog",
        "textAnnotationUpdated",
        "",
        "GeoDataFeature*",
        "feature",
        "relationCreated",
        "OsmPlacemarkData",
        "relation",
        "updateDialogFields",
        "setIdFilter",
        "filter",
        "setTargetIds",
        "targetIds",
        "setTargetIdFieldVisible",
        "visible",
        "setIdFieldVisible",
        "isReadOnly",
        "setReadOnly",
        "state",
        "checkFields",
        "updateTextAnnotation",
        "updateLabelDialog",
        "QColor",
        "color",
        "updateIconDialog",
        "updatePlacemarkAltitude",
        "restoreInitial",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textAnnotationUpdated'
        QtMocHelpers::SignalData<void(GeoDataFeature *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'relationCreated'
        QtMocHelpers::SignalData<void(const OsmPlacemarkData &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'updateDialogFields'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setIdFilter'
        QtMocHelpers::SlotData<void(const QStringList &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Slot 'setTargetIds'
        QtMocHelpers::SlotData<void(const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Slot 'setTargetIdFieldVisible'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setIdFieldVisible'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'isReadOnly'
        QtMocHelpers::SlotData<bool() const>(16, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setReadOnly'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'checkFields'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTextAnnotation'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLabelDialog'
        QtMocHelpers::SlotData<void(const QColor &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'updateIconDialog'
        QtMocHelpers::SlotData<void(const QColor &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'updatePlacemarkAltitude'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'restoreInitial'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditPlacemarkDialog, qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::EditPlacemarkDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t>.metaTypes,
    nullptr
} };

void Marble::EditPlacemarkDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditPlacemarkDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textAnnotationUpdated((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 1: _t->relationCreated((*reinterpret_cast<std::add_pointer_t<OsmPlacemarkData>>(_a[1]))); break;
        case 2: _t->updateDialogFields(); break;
        case 3: _t->setIdFilter((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->setTargetIds((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->setTargetIdFieldVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setIdFieldVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: { bool _r = _t->isReadOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setReadOnly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->checkFields(); break;
        case 10: _t->updateTextAnnotation(); break;
        case 11: _t->updateLabelDialog((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 12: _t->updateIconDialog((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 13: _t->updatePlacemarkAltitude(); break;
        case 14: _t->restoreInitial((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditPlacemarkDialog::*)(GeoDataFeature * )>(_a, &EditPlacemarkDialog::textAnnotationUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditPlacemarkDialog::*)(const OsmPlacemarkData & )>(_a, &EditPlacemarkDialog::relationCreated, 1))
            return;
    }
}

const QMetaObject *Marble::EditPlacemarkDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::EditPlacemarkDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19EditPlacemarkDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Marble::EditPlacemarkDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Marble::EditPlacemarkDialog::textAnnotationUpdated(GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::EditPlacemarkDialog::relationCreated(const OsmPlacemarkData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
