/********************************************************************************
** Form generated from reading UI file 'MeasureConfigDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MEASURECONFIGDIALOG_H
#define UI_MEASURECONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MeasureConfigDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *modeLabel;
    QComboBox *m_modeCombo;
    QTabWidget *tabWidget;
    QWidget *tab_1;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *m_showDistanceLabelsCheckBox;
    QCheckBox *m_showBearingLabelsCheckBox;
    QCheckBox *m_showBearingLabelChangeCheckBox;
    QCheckBox *m_showPerimeter;
    QCheckBox *m_showPolygonAreaLabelChangeCheckBox;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *m_showRadiusLabelsCheckBox;
    QCheckBox *m_showCircumference;
    QCheckBox *m_showCircleAreaLabelChangeCheckBox;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *MeasureConfigDialog)
    {
        if (MeasureConfigDialog->objectName().isEmpty())
            MeasureConfigDialog->setObjectName("MeasureConfigDialog");
        MeasureConfigDialog->resize(400, 348);
        verticalLayout = new QVBoxLayout(MeasureConfigDialog);
        verticalLayout->setObjectName("verticalLayout");
        modeLabel = new QLabel(MeasureConfigDialog);
        modeLabel->setObjectName("modeLabel");

        verticalLayout->addWidget(modeLabel);

        m_modeCombo = new QComboBox(MeasureConfigDialog);
        m_modeCombo->addItem(QString());
        m_modeCombo->addItem(QString());
        m_modeCombo->setObjectName("m_modeCombo");

        verticalLayout->addWidget(m_modeCombo);

        tabWidget = new QTabWidget(MeasureConfigDialog);
        tabWidget->setObjectName("tabWidget");
        tab_1 = new QWidget();
        tab_1->setObjectName("tab_1");
        verticalLayout_3 = new QVBoxLayout(tab_1);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox = new QGroupBox(tab_1);
        groupBox->setObjectName("groupBox");
        groupBox->setCheckable(false);
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_showDistanceLabelsCheckBox = new QCheckBox(groupBox);
        m_showDistanceLabelsCheckBox->setObjectName("m_showDistanceLabelsCheckBox");
        m_showDistanceLabelsCheckBox->setChecked(true);

        verticalLayout_2->addWidget(m_showDistanceLabelsCheckBox);

        m_showBearingLabelsCheckBox = new QCheckBox(groupBox);
        m_showBearingLabelsCheckBox->setObjectName("m_showBearingLabelsCheckBox");
        m_showBearingLabelsCheckBox->setChecked(true);

        verticalLayout_2->addWidget(m_showBearingLabelsCheckBox);

        m_showBearingLabelChangeCheckBox = new QCheckBox(groupBox);
        m_showBearingLabelChangeCheckBox->setObjectName("m_showBearingLabelChangeCheckBox");
        m_showBearingLabelChangeCheckBox->setChecked(true);

        verticalLayout_2->addWidget(m_showBearingLabelChangeCheckBox);

        m_showPerimeter = new QCheckBox(groupBox);
        m_showPerimeter->setObjectName("m_showPerimeter");

        verticalLayout_2->addWidget(m_showPerimeter);

        m_showPolygonAreaLabelChangeCheckBox = new QCheckBox(groupBox);
        m_showPolygonAreaLabelChangeCheckBox->setObjectName("m_showPolygonAreaLabelChangeCheckBox");
        m_showPolygonAreaLabelChangeCheckBox->setEnabled(true);
        m_showPolygonAreaLabelChangeCheckBox->setChecked(false);

        verticalLayout_2->addWidget(m_showPolygonAreaLabelChangeCheckBox);


        verticalLayout_3->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        tabWidget->addTab(tab_1, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_5 = new QVBoxLayout(tab_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        groupBox_2 = new QGroupBox(tab_2);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setCheckable(false);
        verticalLayout_4 = new QVBoxLayout(groupBox_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        m_showRadiusLabelsCheckBox = new QCheckBox(groupBox_2);
        m_showRadiusLabelsCheckBox->setObjectName("m_showRadiusLabelsCheckBox");
        m_showRadiusLabelsCheckBox->setChecked(true);

        verticalLayout_4->addWidget(m_showRadiusLabelsCheckBox);

        m_showCircumference = new QCheckBox(groupBox_2);
        m_showCircumference->setObjectName("m_showCircumference");

        verticalLayout_4->addWidget(m_showCircumference);

        m_showCircleAreaLabelChangeCheckBox = new QCheckBox(groupBox_2);
        m_showCircleAreaLabelChangeCheckBox->setObjectName("m_showCircleAreaLabelChangeCheckBox");
        m_showCircleAreaLabelChangeCheckBox->setChecked(true);

        verticalLayout_4->addWidget(m_showCircleAreaLabelChangeCheckBox);


        verticalLayout_5->addWidget(groupBox_2);

        verticalSpacer_2 = new QSpacerItem(20, 70, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        tabWidget->addTab(tab_2, QString());

        verticalLayout->addWidget(tabWidget);

        m_buttonBox = new QDialogButtonBox(MeasureConfigDialog);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(MeasureConfigDialog);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, MeasureConfigDialog, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, MeasureConfigDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MeasureConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *MeasureConfigDialog)
    {
        MeasureConfigDialog->setWindowTitle(QCoreApplication::translate("MeasureConfigDialog", "Measure Tool Configuration", nullptr));
        modeLabel->setText(QCoreApplication::translate("MeasureConfigDialog", "Ruler Type", nullptr));
        m_modeCombo->setItemText(0, QCoreApplication::translate("MeasureConfigDialog", "Polygon", nullptr));
        m_modeCombo->setItemText(1, QCoreApplication::translate("MeasureConfigDialog", "Circle", nullptr));

        groupBox->setTitle(QCoreApplication::translate("MeasureConfigDialog", "Segment labels", nullptr));
        m_showDistanceLabelsCheckBox->setText(QCoreApplication::translate("MeasureConfigDialog", "Distance ", nullptr));
        m_showBearingLabelsCheckBox->setText(QCoreApplication::translate("MeasureConfigDialog", "Bearing", nullptr));
        m_showBearingLabelChangeCheckBox->setText(QCoreApplication::translate("MeasureConfigDialog", "Bearing Change", nullptr));
        m_showPerimeter->setText(QCoreApplication::translate("MeasureConfigDialog", "Perimeter", nullptr));
        m_showPolygonAreaLabelChangeCheckBox->setText(QCoreApplication::translate("MeasureConfigDialog", "Area", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_1), QCoreApplication::translate("MeasureConfigDialog", "Polygon", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("MeasureConfigDialog", "Labels", nullptr));
        m_showRadiusLabelsCheckBox->setText(QCoreApplication::translate("MeasureConfigDialog", "Radius", nullptr));
        m_showCircumference->setText(QCoreApplication::translate("MeasureConfigDialog", "Circumference", nullptr));
        m_showCircleAreaLabelChangeCheckBox->setText(QCoreApplication::translate("MeasureConfigDialog", "Area", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("MeasureConfigDialog", "Circle", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MeasureConfigDialog: public Ui_MeasureConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MEASURECONFIGDIALOG_H
