/********************************************************************************
** Form generated from reading UI file 'EarthquakeConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EARTHQUAKECONFIGWIDGET_H
#define UI_EARTHQUAKECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_EarthquakeConfigWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout_2;
    QLabel *label;
    QSpinBox *m_numResults;
    QLabel *label_2;
    QDoubleSpinBox *m_minMagnitude;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QRadioButton *m_timeRangeNPastDaysRadioButton;
    QRadioButton *m_timeRangeFromToRadioButton;
    QWidget *widget;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *m_pastDays;
    QLabel *label_5;
    QSpacerItem *horizontalSpacer;
    QWidget *widget_2;
    QHBoxLayout *horizontalLayout_4;
    QDateTimeEdit *m_startDate;
    QLabel *label_4;
    QDateTimeEdit *m_endDate;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;
    QButtonGroup *timeRangeRadioButtonGroup;

    void setupUi(QDialog *EarthquakeConfigWidget)
    {
        if (EarthquakeConfigWidget->objectName().isEmpty())
            EarthquakeConfigWidget->setObjectName("EarthquakeConfigWidget");
        EarthquakeConfigWidget->resize(436, 233);
        gridLayout = new QGridLayout(EarthquakeConfigWidget);
        gridLayout->setObjectName("gridLayout");
        groupBox_2 = new QGroupBox(EarthquakeConfigWidget);
        groupBox_2->setObjectName("groupBox_2");
        formLayout_2 = new QFormLayout(groupBox_2);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        m_numResults = new QSpinBox(groupBox_2);
        m_numResults->setObjectName("m_numResults");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, m_numResults);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        m_minMagnitude = new QDoubleSpinBox(groupBox_2);
        m_minMagnitude->setObjectName("m_minMagnitude");
        m_minMagnitude->setMaximum(10.000000000000000);
        m_minMagnitude->setSingleStep(0.500000000000000);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, m_minMagnitude);


        gridLayout->addWidget(groupBox_2, 0, 0, 1, 1);

        groupBox = new QGroupBox(EarthquakeConfigWidget);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        m_timeRangeNPastDaysRadioButton = new QRadioButton(groupBox);
        timeRangeRadioButtonGroup = new QButtonGroup(EarthquakeConfigWidget);
        timeRangeRadioButtonGroup->setObjectName("timeRangeRadioButtonGroup");
        timeRangeRadioButtonGroup->addButton(m_timeRangeNPastDaysRadioButton);
        m_timeRangeNPastDaysRadioButton->setObjectName("m_timeRangeNPastDaysRadioButton");
        m_timeRangeNPastDaysRadioButton->setChecked(true);

        gridLayout_2->addWidget(m_timeRangeNPastDaysRadioButton, 0, 0, 1, 1);

        m_timeRangeFromToRadioButton = new QRadioButton(groupBox);
        timeRangeRadioButtonGroup->addButton(m_timeRangeFromToRadioButton);
        m_timeRangeFromToRadioButton->setObjectName("m_timeRangeFromToRadioButton");

        gridLayout_2->addWidget(m_timeRangeFromToRadioButton, 1, 0, 1, 1);

        widget = new QWidget(groupBox);
        widget->setObjectName("widget");
        widget->setEnabled(true);
        horizontalLayout_2 = new QHBoxLayout(widget);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_pastDays = new QSpinBox(widget);
        m_pastDays->setObjectName("m_pastDays");
        m_pastDays->setMinimum(2);
        m_pastDays->setMaximum(999);
        m_pastDays->setValue(30);

        horizontalLayout_2->addWidget(m_pastDays);

        label_5 = new QLabel(widget);
        label_5->setObjectName("label_5");

        horizontalLayout_2->addWidget(label_5);

        horizontalSpacer = new QSpacerItem(73, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout_2->addWidget(widget, 0, 1, 1, 1);

        widget_2 = new QWidget(groupBox);
        widget_2->setObjectName("widget_2");
        widget_2->setEnabled(false);
        horizontalLayout_4 = new QHBoxLayout(widget_2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        m_startDate = new QDateTimeEdit(widget_2);
        m_startDate->setObjectName("m_startDate");
        m_startDate->setDateTime(QDateTime(QDate(2006, 2, 4), QTime(0, 0, 0)));

        horizontalLayout_4->addWidget(m_startDate);

        label_4 = new QLabel(widget_2);
        label_4->setObjectName("label_4");

        horizontalLayout_4->addWidget(label_4);

        m_endDate = new QDateTimeEdit(widget_2);
        m_endDate->setObjectName("m_endDate");
        m_endDate->setDateTime(QDateTime(QDate(2006, 2, 4), QTime(0, 0, 0)));

        horizontalLayout_4->addWidget(m_endDate);

        horizontalSpacer_2 = new QSpacerItem(101, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        gridLayout_2->addWidget(widget_2, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 1, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 1);

        m_buttonBox = new QDialogButtonBox(EarthquakeConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(m_buttonBox, 2, 0, 1, 1);


        retranslateUi(EarthquakeConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, EarthquakeConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, EarthquakeConfigWidget, qOverload<>(&QDialog::reject));
        QObject::connect(m_timeRangeFromToRadioButton, &QRadioButton::toggled, widget_2, &QWidget::setEnabled);
        QObject::connect(m_timeRangeNPastDaysRadioButton, &QRadioButton::toggled, widget, &QWidget::setEnabled);

        QMetaObject::connectSlotsByName(EarthquakeConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *EarthquakeConfigWidget)
    {
        EarthquakeConfigWidget->setWindowTitle(QCoreApplication::translate("EarthquakeConfigWidget", "Configure Earthquakes Plugin", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("EarthquakeConfigWidget", "Filter", nullptr));
        label->setText(QCoreApplication::translate("EarthquakeConfigWidget", "Maximum number of results:", nullptr));
        label_2->setText(QCoreApplication::translate("EarthquakeConfigWidget", "Minimum magnitude:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("EarthquakeConfigWidget", "Time Range", nullptr));
        m_timeRangeNPastDaysRadioButton->setText(QCoreApplication::translate("EarthquakeConfigWidget", "Past", nullptr));
        m_timeRangeFromToRadioButton->setText(QCoreApplication::translate("EarthquakeConfigWidget", "From", nullptr));
        label_5->setText(QCoreApplication::translate("EarthquakeConfigWidget", "days", nullptr));
        label_4->setText(QCoreApplication::translate("EarthquakeConfigWidget", "to", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EarthquakeConfigWidget: public Ui_EarthquakeConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EARTHQUAKECONFIGWIDGET_H
