/****************************************************************************
** Meta object code from reading C++ file 'TileLoader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/TileLoader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TileLoader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble10TileLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::TileLoader::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble10TileLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::TileLoader",
        "tileRequested",
        "",
        "QUrl",
        "sourceUrl",
        "destinationFileName",
        "id",
        "DownloadUsage",
        "tileCompleted",
        "TileId",
        "tileId",
        "QImage",
        "tileImage",
        "GeoDataDocument*",
        "document",
        "updateTile",
        "imageData",
        "fileName",
        "idStr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tileRequested'
        QtMocHelpers::SignalData<void(QUrl const &, QString const &, QString const &, DownloadUsage)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { 0x80000000 | 7, 2 },
        }}),
        // Signal 'tileCompleted'
        QtMocHelpers::SignalData<void(TileId const &, QImage const &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'tileCompleted'
        QtMocHelpers::SignalData<void(TileId const &, GeoDataDocument *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'updateTile'
        QtMocHelpers::SlotData<void(QByteArray const &, QString const &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 16 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'updateTile'
        QtMocHelpers::SlotData<void(QString const &, QString const &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TileLoader, qt_meta_tag_ZN6Marble10TileLoaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::TileLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TileLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TileLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble10TileLoaderE_t>.metaTypes,
    nullptr
} };

void Marble::TileLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TileLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tileRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<DownloadUsage>>(_a[4]))); break;
        case 1: _t->tileCompleted((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QImage>>(_a[2]))); break;
        case 2: _t->tileCompleted((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[2]))); break;
        case 3: _t->updateTile((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->updateTile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TileLoader::*)(QUrl const & , QString const & , QString const & , DownloadUsage )>(_a, &TileLoader::tileRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TileLoader::*)(TileId const & , QImage const & )>(_a, &TileLoader::tileCompleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TileLoader::*)(TileId const & , GeoDataDocument * )>(_a, &TileLoader::tileCompleted, 2))
            return;
    }
}

const QMetaObject *Marble::TileLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::TileLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TileLoaderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::TileLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Marble::TileLoader::tileRequested(QUrl const & _t1, QString const & _t2, QString const & _t3, DownloadUsage _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void Marble::TileLoader::tileCompleted(TileId const & _t1, QImage const & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Marble::TileLoader::tileCompleted(TileId const & _t1, GeoDataDocument * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
