/****************************************************************************
** Meta object code from reading C++ file 'TourItemDelegate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/TourItemDelegate.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TourItemDelegate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble16TourItemDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::TourItemDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble16TourItemDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::TourItemDelegate",
        "editingChanged",
        "",
        "QModelIndex",
        "index",
        "edited",
        "editableChanged",
        "editable",
        "firstFlyToChanged",
        "QPersistentModelIndex",
        "newFirstFlyTo",
        "featureIdsChanged",
        "ids",
        "defaultFeatureIdChanged",
        "id",
        "setFirstFlyTo",
        "setDefaultFeatureId",
        "closeEditor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'editingChanged'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'edited'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'editableChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'firstFlyToChanged'
        QtMocHelpers::SignalData<void(const QPersistentModelIndex &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'featureIdsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Signal 'defaultFeatureIdChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setFirstFlyTo'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 4 },
        }}),
        // Slot 'setDefaultFeatureId'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'closeEditor'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TourItemDelegate, qt_meta_tag_ZN6Marble16TourItemDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::TourItemDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QStyledItemDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16TourItemDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16TourItemDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble16TourItemDelegateE_t>.metaTypes,
    nullptr
} };

void Marble::TourItemDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TourItemDelegate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->editingChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 1: _t->edited((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->editableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->firstFlyToChanged((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 4: _t->featureIdsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->defaultFeatureIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setFirstFlyTo((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 7: _t->setDefaultFeatureId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->closeEditor((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TourItemDelegate::*)(const QModelIndex & )>(_a, &TourItemDelegate::editingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourItemDelegate::*)(const QModelIndex & )>(_a, &TourItemDelegate::edited, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourItemDelegate::*)(bool )>(_a, &TourItemDelegate::editableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourItemDelegate::*)(const QPersistentModelIndex & )>(_a, &TourItemDelegate::firstFlyToChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourItemDelegate::*)(const QStringList & )>(_a, &TourItemDelegate::featureIdsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourItemDelegate::*)(const QString & )>(_a, &TourItemDelegate::defaultFeatureIdChanged, 5))
            return;
    }
}

const QMetaObject *Marble::TourItemDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::TourItemDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16TourItemDelegateE_t>.strings))
        return static_cast<void*>(this);
    return QStyledItemDelegate::qt_metacast(_clname);
}

int Marble::TourItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStyledItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Marble::TourItemDelegate::editingChanged(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::TourItemDelegate::edited(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::TourItemDelegate::editableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::TourItemDelegate::firstFlyToChanged(const QPersistentModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::TourItemDelegate::featureIdsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::TourItemDelegate::defaultFeatureIdChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
