/****************************************************************************
** Meta object code from reading C++ file 'OwncloudSyncBackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/cloudsync/OwncloudSyncBackend.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OwncloudSyncBackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::OwncloudSyncBackend::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::OwncloudSyncBackend",
        "routeListDownloaded",
        "",
        "QList<RouteItem>",
        "routeList",
        "routeDownloaded",
        "routeDeleted",
        "routeUploadProgress",
        "sent",
        "total",
        "routeDownloadProgress",
        "received",
        "routeListDownloadProgress",
        "removedFromCache",
        "timestamp",
        "cancelUpload",
        "checkAuthReply",
        "checkAuthError",
        "QNetworkReply::NetworkError",
        "error",
        "prepareRouteList",
        "saveDownloadedRoute",
        "validateSettings"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'routeListDownloaded'
        QtMocHelpers::SignalData<void(const QList<RouteItem> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'routeDownloaded'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'routeDeleted'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'routeUploadProgress'
        QtMocHelpers::SignalData<void(qint64, qint64)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 8 }, { QMetaType::LongLong, 9 },
        }}),
        // Signal 'routeDownloadProgress'
        QtMocHelpers::SignalData<void(qint64, qint64)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 11 }, { QMetaType::LongLong, 9 },
        }}),
        // Signal 'routeListDownloadProgress'
        QtMocHelpers::SignalData<void(qint64, qint64)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 11 }, { QMetaType::LongLong, 9 },
        }}),
        // Signal 'removedFromCache'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'cancelUpload'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkAuthReply'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkAuthError'
        QtMocHelpers::SlotData<void(QNetworkReply::NetworkError)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'prepareRouteList'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveDownloadedRoute'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'validateSettings'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OwncloudSyncBackend, qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::OwncloudSyncBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t>.metaTypes,
    nullptr
} };

void Marble::OwncloudSyncBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OwncloudSyncBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->routeListDownloaded((*reinterpret_cast<std::add_pointer_t<QList<RouteItem>>>(_a[1]))); break;
        case 1: _t->routeDownloaded(); break;
        case 2: _t->routeDeleted(); break;
        case 3: _t->routeUploadProgress((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 4: _t->routeDownloadProgress((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 5: _t->routeListDownloadProgress((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 6: _t->removedFromCache((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->cancelUpload(); break;
        case 8: _t->checkAuthReply(); break;
        case 9: _t->checkAuthError((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1]))); break;
        case 10: _t->prepareRouteList(); break;
        case 11: _t->saveDownloadedRoute(); break;
        case 12: _t->validateSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)(const QList<RouteItem> & )>(_a, &OwncloudSyncBackend::routeListDownloaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)()>(_a, &OwncloudSyncBackend::routeDownloaded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)()>(_a, &OwncloudSyncBackend::routeDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)(qint64 , qint64 )>(_a, &OwncloudSyncBackend::routeUploadProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)(qint64 , qint64 )>(_a, &OwncloudSyncBackend::routeDownloadProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)(qint64 , qint64 )>(_a, &OwncloudSyncBackend::routeListDownloadProgress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwncloudSyncBackend::*)(const QString & )>(_a, &OwncloudSyncBackend::removedFromCache, 6))
            return;
    }
}

const QMetaObject *Marble::OwncloudSyncBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::OwncloudSyncBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19OwncloudSyncBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::OwncloudSyncBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Marble::OwncloudSyncBackend::routeListDownloaded(const QList<RouteItem> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::OwncloudSyncBackend::routeDownloaded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::OwncloudSyncBackend::routeDeleted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::OwncloudSyncBackend::routeUploadProgress(qint64 _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Marble::OwncloudSyncBackend::routeDownloadProgress(qint64 _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Marble::OwncloudSyncBackend::routeListDownloadProgress(qint64 _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Marble::OwncloudSyncBackend::removedFromCache(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
