/********************************************************************************
** Form generated from reading UI file 'RoutingConfigDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROUTINGCONFIGDIALOG_H
#define UI_ROUTINGCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_RoutingConfigDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QCheckBox *voiceNavigationCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QRadioButton *soundRadioButton;
    QHBoxLayout *horizontalLayout;
    QRadioButton *speakerRadioButton;
    QComboBox *speakerComboBox;
    QLabel *label_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *RoutingConfigDialog)
    {
        if (RoutingConfigDialog->objectName().isEmpty())
            RoutingConfigDialog->setObjectName("RoutingConfigDialog");
        RoutingConfigDialog->resize(332, 139);
        verticalLayout_2 = new QVBoxLayout(RoutingConfigDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        voiceNavigationCheckBox = new QCheckBox(RoutingConfigDialog);
        voiceNavigationCheckBox->setObjectName("voiceNavigationCheckBox");
        voiceNavigationCheckBox->setChecked(true);

        verticalLayout_2->addWidget(voiceNavigationCheckBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(30, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        soundRadioButton = new QRadioButton(RoutingConfigDialog);
        soundRadioButton->setObjectName("soundRadioButton");
        soundRadioButton->setChecked(true);

        verticalLayout->addWidget(soundRadioButton);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        speakerRadioButton = new QRadioButton(RoutingConfigDialog);
        speakerRadioButton->setObjectName("speakerRadioButton");
        speakerRadioButton->setChecked(false);

        horizontalLayout->addWidget(speakerRadioButton);

        speakerComboBox = new QComboBox(RoutingConfigDialog);
        speakerComboBox->setObjectName("speakerComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(speakerComboBox->sizePolicy().hasHeightForWidth());
        speakerComboBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(speakerComboBox);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout_2);

        label_2 = new QLabel(RoutingConfigDialog);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setOpenExternalLinks(true);

        verticalLayout_2->addWidget(label_2);

        buttonBox = new QDialogButtonBox(RoutingConfigDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(RoutingConfigDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, RoutingConfigDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, RoutingConfigDialog, qOverload<>(&QDialog::reject));
        QObject::connect(voiceNavigationCheckBox, &QCheckBox::toggled, speakerComboBox, &QComboBox::setEnabled);
        QObject::connect(voiceNavigationCheckBox, &QCheckBox::toggled, speakerRadioButton, &QRadioButton::setEnabled);
        QObject::connect(voiceNavigationCheckBox, &QCheckBox::toggled, soundRadioButton, &QRadioButton::setEnabled);
        QObject::connect(speakerComboBox, &QComboBox::currentIndexChanged, speakerRadioButton, qOverload<>(&QRadioButton::click));

        QMetaObject::connectSlotsByName(RoutingConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *RoutingConfigDialog)
    {
        RoutingConfigDialog->setWindowTitle(QCoreApplication::translate("RoutingConfigDialog", "Routing Configuration", nullptr));
        voiceNavigationCheckBox->setText(QCoreApplication::translate("RoutingConfigDialog", "Audible Turn Instructions", nullptr));
        soundRadioButton->setText(QCoreApplication::translate("RoutingConfigDialog", "Play a sound", nullptr));
        speakerRadioButton->setText(QCoreApplication::translate("RoutingConfigDialog", "Use this speaker", nullptr));
        label_2->setText(QCoreApplication::translate("RoutingConfigDialog", "<a href=\"https://userbase.kde.org/Marble/CustomSpeakers\">Get more speakers</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RoutingConfigDialog: public Ui_RoutingConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ROUTINGCONFIGDIALOG_H
