/****************************************************************************
** Meta object code from reading C++ file 'SearchBackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.1/src/lib/marble/declarative/SearchBackend.h"
#include "MarbleQuickItem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SearchBackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble13SearchBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::SearchBackend::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble13SearchBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::SearchBackend",
        "QML.Element",
        "auto",
        "marbleQuickItemChanged",
        "",
        "marbleQuickItem",
        "completionModelChanged",
        "MarblePlacemarkModel*",
        "model",
        "searchResultChanged",
        "searchFinished",
        "searchTerm",
        "selectedPlacemarkChanged",
        "Placemark*",
        "selectedPlacemark",
        "setSelectedPlacemark",
        "placemarkIndex",
        "setMarbleQuickItem",
        "updateSearchResult",
        "QAbstractItemModel*",
        "result",
        "search",
        "place",
        "setCompletionPrefix",
        "prefix",
        "completionModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'marbleQuickItemChanged'
        QtMocHelpers::SignalData<void(QObject *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Signal 'completionModelChanged'
        QtMocHelpers::SignalData<void(MarblePlacemarkModel *)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'searchResultChanged'
        QtMocHelpers::SignalData<void(MarblePlacemarkModel *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'searchFinished'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'selectedPlacemarkChanged'
        QtMocHelpers::SignalData<void(Placemark *)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setSelectedPlacemark'
        QtMocHelpers::SlotData<void(int)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setMarbleQuickItem'
        QtMocHelpers::SlotData<void(QObject *)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Slot 'updateSearchResult'
        QtMocHelpers::SlotData<void(QAbstractItemModel *)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Method 'search'
        QtMocHelpers::MethodData<void(const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'setCompletionPrefix'
        QtMocHelpers::MethodData<void(const QString &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'marbleQuickItem'
        QtMocHelpers::PropertyData<QObject*>(5, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'completionModel'
        QtMocHelpers::PropertyData<MarblePlacemarkModel*>(25, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'selectedPlacemark'
        QtMocHelpers::PropertyData<Placemark*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SearchBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::SearchBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13SearchBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13SearchBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble13SearchBackendE_t>.metaTypes,
    nullptr
} };

void Marble::SearchBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->marbleQuickItemChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 1: _t->completionModelChanged((*reinterpret_cast<std::add_pointer_t<MarblePlacemarkModel*>>(_a[1]))); break;
        case 2: _t->searchResultChanged((*reinterpret_cast<std::add_pointer_t<MarblePlacemarkModel*>>(_a[1]))); break;
        case 3: _t->searchFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->selectedPlacemarkChanged((*reinterpret_cast<std::add_pointer_t<Placemark*>>(_a[1]))); break;
        case 5: _t->setSelectedPlacemark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setMarbleQuickItem((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 7: _t->updateSearchResult((*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[1]))); break;
        case 8: _t->search((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setCompletionPrefix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MarblePlacemarkModel* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MarblePlacemarkModel* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Placemark* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractItemModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchBackend::*)(QObject * )>(_a, &SearchBackend::marbleQuickItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchBackend::*)(MarblePlacemarkModel * )>(_a, &SearchBackend::completionModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchBackend::*)(MarblePlacemarkModel * )>(_a, &SearchBackend::searchResultChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchBackend::*)(const QString & )>(_a, &SearchBackend::searchFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchBackend::*)(Placemark * )>(_a, &SearchBackend::selectedPlacemarkChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MarblePlacemarkModel* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Placemark* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->marbleQuickItem(); break;
        case 1: *reinterpret_cast<MarblePlacemarkModel**>(_v) = _t->completionModel(); break;
        case 2: *reinterpret_cast<Placemark**>(_v) = _t->selectedPlacemark(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMarbleQuickItem(*reinterpret_cast<QObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::SearchBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::SearchBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13SearchBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::SearchBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Marble::SearchBackend::marbleQuickItemChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::SearchBackend::completionModelChanged(MarblePlacemarkModel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::SearchBackend::searchResultChanged(MarblePlacemarkModel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::SearchBackend::searchFinished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::SearchBackend::selectedPlacemarkChanged(Placemark * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
