/****************************************************************************
** Meta object code from reading C++ file 'ControlView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/apps/marble-ui/ControlView.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ControlView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble11ControlViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::ControlView::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble11ControlViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::ControlView",
        "showMapWizard",
        "",
        "mapThemeDeleted",
        "printMapScreenShot",
        "QPointer<QPrintDialog>",
        "dialog",
        "printPreview",
        "paintPrintPreview",
        "QPrinter*",
        "printer",
        "launchExternalMapEditor",
        "togglePanelVisibility",
        "handleTourLinkClicked",
        "path",
        "openTour",
        "filename",
        "showSearch",
        "showConflictDialog",
        "MergeItem*",
        "item",
        "updateAnnotationDockVisibility",
        "updateAnnotationDock"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showMapWizard'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapThemeDeleted'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printMapScreenShot'
        QtMocHelpers::SlotData<void(const QPointer<QPrintDialog> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paintPrintPreview'
        QtMocHelpers::SlotData<void(QPrinter *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'launchExternalMapEditor'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePanelVisibility'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleTourLinkClicked'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'openTour'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'showSearch'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showConflictDialog'
        QtMocHelpers::SlotData<void(MergeItem *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'updateAnnotationDockVisibility'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAnnotationDock'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ControlView, qt_meta_tag_ZN6Marble11ControlViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::ControlView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11ControlViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11ControlViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble11ControlViewE_t>.metaTypes,
    nullptr
} };

void Marble::ControlView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ControlView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showMapWizard(); break;
        case 1: _t->mapThemeDeleted(); break;
        case 2: _t->printMapScreenShot((*reinterpret_cast<std::add_pointer_t<QPointer<QPrintDialog>>>(_a[1]))); break;
        case 3: _t->printPreview(); break;
        case 4: _t->paintPrintPreview((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 5: _t->launchExternalMapEditor(); break;
        case 6: _t->togglePanelVisibility(); break;
        case 7: _t->handleTourLinkClicked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->openTour((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->showSearch(); break;
        case 10: _t->showConflictDialog((*reinterpret_cast<std::add_pointer_t<MergeItem*>>(_a[1]))); break;
        case 11: _t->updateAnnotationDockVisibility(); break;
        case 12: _t->updateAnnotationDock(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ControlView::*)()>(_a, &ControlView::showMapWizard, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlView::*)()>(_a, &ControlView::mapThemeDeleted, 1))
            return;
    }
}

const QMetaObject *Marble::ControlView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::ControlView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble11ControlViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::ControlView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Marble::ControlView::showMapWizard()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::ControlView::mapThemeDeleted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
