/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // flag-red-mirrored.png
  0x0,0x0,0x2,0x66,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x37,0x5c,0x0,0x0,0x37,0x5c,
  0x1,0xcb,0xc7,0xa4,0xb9,0x0,0x0,0x2,0x8,0x49,0x44,0x41,0x54,0x38,0x8d,0x9d,
  0x92,0x41,0x6b,0x53,0x41,0x14,0x85,0xbf,0x99,0x4c,0x5e,0xda,0xc6,0x56,0x1b,0x29,
  0xa8,0x14,0xb,0x5a,0xa9,0xad,0xa1,0xa0,0xdd,0xb5,0x71,0xe1,0xc2,0xd2,0x85,0x74,
  0x97,0xbd,0x7f,0xc0,0x85,0xf8,0x3,0x5e,0xb3,0x71,0xed,0xae,0xff,0x40,0xa4,0x6f,
  0xaf,0x8,0x15,0x14,0xa,0xae,0x14,0x44,0x12,0xa,0x16,0x21,0x2d,0x85,0x96,0x90,
  0x48,0xd2,0xe6,0x25,0x7d,0x33,0xf3,0xc6,0x45,0x5e,0x63,0xac,0xa,0xc5,0x3,0x3,
  0x77,0xee,0xb9,0xf7,0xdc,0x33,0xcc,0x85,0x73,0xc2,0x7,0x9,0xb0,0x30,0x37,0x77,
  0x7d,0x75,0x75,0xf5,0x23,0x30,0xa,0xa0,0x6,0xb,0xd6,0x7c,0x9f,0xb5,0xe4,0x7e,
  0xa7,0x52,0x11,0xa7,0x5c,0x31,0x8,0x62,0x1,0x31,0xc0,0xce,0xfe,0x7e,0xab,0x1e,
  0x86,0x65,0xdf,0xf7,0xdb,0xa5,0x52,0xe9,0xbc,0xf3,0xe1,0xf9,0xe8,0xe8,0xe5,0x27,
  0x23,0x23,0x2b,0x8b,0x4a,0x6d,0xcc,0xce,0xcc,0x54,0x9c,0x73,0xb2,0xef,0xc0,0x7,
  0x6f,0x76,0x7e,0xfe,0xc1,0x95,0xa5,0xa5,0xac,0x69,0x36,0x7f,0x84,0xb5,0xda,0x90,
  0x33,0xe6,0x92,0xd,0xc3,0xab,0x51,0xb7,0x3b,0x1d,0xb7,0xdb,0xf9,0x83,0x66,0x33,
  0x6f,0x8f,0x8f,0xc7,0xd3,0x52,0xa2,0x94,0xfa,0x6,0x88,0xbe,0x40,0x9,0xa2,0x57,
  0x51,0x54,0x93,0xf0,0x2c,0x97,0xcf,0x3f,0x1c,0x37,0x86,0xf6,0xe1,0x21,0x27,0x8d,
  0x6,0xdd,0x46,0x83,0xa8,0x5e,0xc7,0x8b,0x22,0x44,0x18,0x5a,0xac,0x4d,0x39,0xe7,
  0xfa,0xce,0x24,0x80,0x3,0x21,0xb7,0xb7,0xbf,0xbc,0x5b,0x5f,0x7f,0xb4,0xb3,0xb9,
  0xf9,0xf4,0x60,0x6f,0xaf,0xad,0x3c,0xcf,0xa8,0x4c,0x46,0x8b,0x54,0xca,0x22,0x65,
  0x2c,0xa4,0xec,0xd7,0xf,0x42,0x1,0xac,0x81,0xb8,0x35,0x35,0xb5,0x5c,0x58,0x5c,
  0x7c,0xac,0x72,0xb9,0xfb,0x8d,0x4e,0x27,0x5b,0xdd,0xdd,0x65,0x38,0x8a,0x50,0x5a,
  0x23,0xac,0x8d,0xad,0x31,0x36,0xee,0x8d,0x56,0xb1,0xb5,0x4,0x83,0x2,0x25,0x88,
  0xa9,0x56,0xdf,0xf8,0xd5,0xea,0xdb,0xbb,0x85,0xc2,0xed,0x8b,0x13,0x13,0xcb,0xc7,
  0x5a,0xaf,0x34,0xea,0xf5,0x7b,0xdd,0x56,0x6b,0x22,0xdd,0xe9,0x48,0xdd,0xe9,0x20,
  0x12,0xef,0xda,0x18,0x8,0x82,0x5f,0x2,0xa7,0xcf,0x10,0x10,0xb3,0xb5,0x55,0x1,
  0x2a,0xc0,0x8b,0xd7,0xb9,0xdc,0xd8,0xd7,0x4c,0x66,0xfa,0xfb,0xd1,0xd1,0x8d,0xb,
  0xce,0x5d,0x13,0xb0,0x10,0x3b,0xb7,0x62,0x8c,0x11,0xfc,0xb,0xe,0xc4,0x46,0xb1,
  0x98,0x72,0xce,0x9d,0x2d,0x12,0x0,0x63,0x70,0x73,0x72,0x72,0xf2,0x53,0xb1,0x58,
  0xf4,0x7e,0x73,0x30,0x50,0xe5,0x8,0x2,0x8b,0xe8,0xf5,0x9f,0x6e,0xe0,0x7b,0x90,
  0x1f,0xc0,0xb4,0xe0,0x24,0x6b,0xad,0x2d,0x97,0xcb,0xfc,0x55,0xe0,0x2c,0x4a,0xc9,
  0x6,0xf6,0xcc,0xf5,0xa0,0xb5,0xee,0xbb,0xfb,0xe3,0x5b,0xce,0x3,0x63,0x4c,0x3f,
  0xfe,0x2f,0x1,0xad,0x75,0x7c,0x36,0x27,0x12,0xb1,0x14,0x90,0x6,0x32,0xc0,0x10,
  0x30,0xc,0x8c,0x24,0x27,0x9b,0xf0,0xd3,0xc0,0xe7,0x84,0x43,0x25,0xcd,0xa,0xf0,
  0x92,0x66,0x6f,0x20,0x4e,0x27,0x5c,0x2a,0x19,0x10,0x1,0x63,0xc0,0xcb,0x24,0xc7,
  0x4f,0x59,0x74,0xd6,0x5e,0x3d,0x99,0x9d,0xd4,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,
  0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // flag-red-mirrored.png
  0x0,0x15,
  0x7,0xa7,0x21,0x67,
  0x0,0x66,
  0x0,0x6c,0x0,0x61,0x0,0x67,0x0,0x2d,0x0,0x72,0x0,0x65,0x0,0x64,0x0,0x2d,0x0,0x6d,0x0,0x69,0x0,0x72,0x0,0x72,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x64,
  0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x6f,0x2f,0x82,0x8,
  // :/flag-red-mirrored.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x6f,0x2f,0x82,0x8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_elevationprofile)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_elevationprofile)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_elevationprofile)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_elevationprofile)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_elevationprofile)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_elevationprofile)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
