//
// SPDX-License-Identifier: LGPL-2.1-or-later
//
// SPDX-FileCopyrightText: 2010 Wes Hardaker <hardaker@users.sourceforge.net>
//

    // Generated automatically by /build/marble/src/marble-26.04.1/src/plugins/render/aprs/AprsGatherGen.pl
#include "AprsGatherer.h"

using namespace Marble;

void AprsGatherer::initMicETables()
{
    m_dstCallDigits['0']          = 0;
    m_dstCallSouthEast['0']       = true;
    m_dstCallLongitudeOffset['0'] = 0;
    m_dstCallMessageBit['0']      = 0;

    m_dstCallDigits['1']          = 1;
    m_dstCallSouthEast['1']       = true;
    m_dstCallLongitudeOffset['1'] = 0;
    m_dstCallMessageBit['1']      = 0;

    m_dstCallDigits['2']          = 2;
    m_dstCallSouthEast['2']       = true;
    m_dstCallLongitudeOffset['2'] = 0;
    m_dstCallMessageBit['2']      = 0;

    m_dstCallDigits['3']          = 3;
    m_dstCallSouthEast['3']       = true;
    m_dstCallLongitudeOffset['3'] = 0;
    m_dstCallMessageBit['3']      = 0;

    m_dstCallDigits['4']          = 4;
    m_dstCallSouthEast['4']       = true;
    m_dstCallLongitudeOffset['4'] = 0;
    m_dstCallMessageBit['4']      = 0;

    m_dstCallDigits['5']          = 5;
    m_dstCallSouthEast['5']       = true;
    m_dstCallLongitudeOffset['5'] = 0;
    m_dstCallMessageBit['5']      = 0;

    m_dstCallDigits['6']          = 6;
    m_dstCallSouthEast['6']       = true;
    m_dstCallLongitudeOffset['6'] = 0;
    m_dstCallMessageBit['6']      = 0;

    m_dstCallDigits['7']          = 7;
    m_dstCallSouthEast['7']       = true;
    m_dstCallLongitudeOffset['7'] = 0;
    m_dstCallMessageBit['7']      = 0;

    m_dstCallDigits['8']          = 8;
    m_dstCallSouthEast['8']       = true;
    m_dstCallLongitudeOffset['8'] = 0;
    m_dstCallMessageBit['8']      = 0;

    m_dstCallDigits['9']          = 9;
    m_dstCallSouthEast['9']       = true;
    m_dstCallLongitudeOffset['9'] = 0;
    m_dstCallMessageBit['9']      = 0;

    m_dstCallDigits['A']          = 0;
    m_dstCallMessageBit['A']      = 2;

    m_dstCallDigits['B']          = 1;
    m_dstCallMessageBit['B']      = 2;

    m_dstCallDigits['C']          = 2;
    m_dstCallMessageBit['C']      = 2;

    m_dstCallDigits['D']          = 3;
    m_dstCallMessageBit['D']      = 2;

    m_dstCallDigits['E']          = 4;
    m_dstCallMessageBit['E']      = 2;

    m_dstCallDigits['F']          = 5;
    m_dstCallMessageBit['F']      = 2;

    m_dstCallDigits['G']          = 6;
    m_dstCallMessageBit['G']      = 2;

    m_dstCallDigits['H']          = 7;
    m_dstCallMessageBit['H']      = 2;

    m_dstCallDigits['I']          = 8;
    m_dstCallMessageBit['I']      = 2;

    m_dstCallDigits['J']          = 9;
    m_dstCallMessageBit['J']      = 2;

    m_dstCallDigits['K']          = 0;
    m_dstCallMessageBit['K']      = 2;

    m_dstCallDigits['L']          = 0;
    m_dstCallMessageBit['L']      = 0;
    m_dstCallLongitudeOffset['L'] = 0;
    m_dstCallSouthEast['L']       = true;

    m_dstCallDigits['P']          = 0;
    m_dstCallSouthEast['P']       = false;
    m_dstCallLongitudeOffset['P'] = 100;
    m_dstCallMessageBit['P']      = 1;

    m_dstCallDigits['Q']          = 1;
    m_dstCallSouthEast['Q']       = false;
    m_dstCallLongitudeOffset['Q'] = 100;
    m_dstCallMessageBit['Q']      = 1;

    m_dstCallDigits['R']          = 2;
    m_dstCallSouthEast['R']       = false;
    m_dstCallLongitudeOffset['R'] = 100;
    m_dstCallMessageBit['R']      = 1;

    m_dstCallDigits['S']          = 3;
    m_dstCallSouthEast['S']       = false;
    m_dstCallLongitudeOffset['S'] = 100;
    m_dstCallMessageBit['S']      = 1;

    m_dstCallDigits['T']          = 4;
    m_dstCallSouthEast['T']       = false;
    m_dstCallLongitudeOffset['T'] = 100;
    m_dstCallMessageBit['T']      = 1;

    m_dstCallDigits['U']          = 5;
    m_dstCallSouthEast['U']       = false;
    m_dstCallLongitudeOffset['U'] = 100;
    m_dstCallMessageBit['U']      = 1;

    m_dstCallDigits['V']          = 6;
    m_dstCallSouthEast['V']       = false;
    m_dstCallLongitudeOffset['V'] = 100;
    m_dstCallMessageBit['V']      = 1;

    m_dstCallDigits['W']          = 7;
    m_dstCallSouthEast['W']       = false;
    m_dstCallLongitudeOffset['W'] = 100;
    m_dstCallMessageBit['W']      = 1;

    m_dstCallDigits['X']          = 8;
    m_dstCallSouthEast['X']       = false;
    m_dstCallLongitudeOffset['X'] = 100;
    m_dstCallMessageBit['X']      = 1;

    m_dstCallDigits['Y']          = 9;
    m_dstCallSouthEast['Y']       = false;
    m_dstCallLongitudeOffset['Y'] = 100;
    m_dstCallMessageBit['Y']      = 1;

    m_dstCallDigits['Z']          = 0;
    m_dstCallMessageBit['Z']      = 1;
    m_dstCallLongitudeOffset['Z'] = 100;
    m_dstCallSouthEast['Z']       = false;


    m_infoFieldByte1[QChar(118)] = 118-1128;
    m_infoFieldByte1[QChar(119)] = 119-1128;
    m_infoFieldByte1[QChar(120)] = 120-1128;
    m_infoFieldByte1[QChar(121)] = 121-1128;
    m_infoFieldByte1[QChar(122)] = 122-1128;
    m_infoFieldByte1[QChar(123)] = 123-1128;
    m_infoFieldByte1[QChar(124)] = 124-1128;
    m_infoFieldByte1[QChar(125)] = 125-1128;
    m_infoFieldByte1[QChar(126)] = 126-1128;
    m_infoFieldByte1[QChar(127)] = 127-1128;
    m_infoFieldByte1[QChar(38)] = 38-28;
    m_infoFieldByte1[QChar(39)] = 39-28;
    m_infoFieldByte1[QChar(40)] = 40-28;
    m_infoFieldByte1[QChar(41)] = 41-28;
    m_infoFieldByte1[QChar(42)] = 42-28;
    m_infoFieldByte1[QChar(43)] = 43-28;
    m_infoFieldByte1[QChar(44)] = 44-28;
    m_infoFieldByte1[QChar(45)] = 45-28;
    m_infoFieldByte1[QChar(46)] = 46-28;
    m_infoFieldByte1[QChar(47)] = 47-28;
    m_infoFieldByte1[QChar(48)] = 48-28;
    m_infoFieldByte1[QChar(49)] = 49-28;
    m_infoFieldByte1[QChar(50)] = 50-28;
    m_infoFieldByte1[QChar(51)] = 51-28;
    m_infoFieldByte1[QChar(52)] = 52-28;
    m_infoFieldByte1[QChar(53)] = 53-28;
    m_infoFieldByte1[QChar(54)] = 54-28;
    m_infoFieldByte1[QChar(55)] = 55-28;
    m_infoFieldByte1[QChar(56)] = 56-28;
    m_infoFieldByte1[QChar(57)] = 57-28;
    m_infoFieldByte1[QChar(58)] = 58-28;
    m_infoFieldByte1[QChar(59)] = 59-28;
    m_infoFieldByte1[QChar(60)] = 60-28;
    m_infoFieldByte1[QChar(61)] = 61-28;
    m_infoFieldByte1[QChar(62)] = 62-28;
    m_infoFieldByte1[QChar(63)] = 63-28;
    m_infoFieldByte1[QChar(64)] = 64-28;
    m_infoFieldByte1[QChar(65)] = 65-28;
    m_infoFieldByte1[QChar(66)] = 66-28;
    m_infoFieldByte1[QChar(67)] = 67-28;
    m_infoFieldByte1[QChar(68)] = 68-28;
    m_infoFieldByte1[QChar(69)] = 69-28;
    m_infoFieldByte1[QChar(70)] = 70-28;
    m_infoFieldByte1[QChar(71)] = 71-28;
    m_infoFieldByte1[QChar(72)] = 72-28;
    m_infoFieldByte1[QChar(73)] = 73-28;
    m_infoFieldByte1[QChar(74)] = 74-28;
    m_infoFieldByte1[QChar(75)] = 75-28;
    m_infoFieldByte1[QChar(76)] = 76-28;
    m_infoFieldByte1[QChar(77)] = 77-28;
    m_infoFieldByte1[QChar(78)] = 78-28;
    m_infoFieldByte1[QChar(79)] = 79-28;
    m_infoFieldByte1[QChar(80)] = 80-28;
    m_infoFieldByte1[QChar(81)] = 81-28;
    m_infoFieldByte1[QChar(82)] = 82-28;
    m_infoFieldByte1[QChar(83)] = 83-28;
    m_infoFieldByte1[QChar(84)] = 84-28;
    m_infoFieldByte1[QChar(85)] = 85-28;
    m_infoFieldByte1[QChar(86)] = 86-28;
    m_infoFieldByte1[QChar(87)] = 87-28;
    m_infoFieldByte1[QChar(88)] = 88-28;
    m_infoFieldByte1[QChar(89)] = 89-28;
    m_infoFieldByte1[QChar(90)] = 90-28;
    m_infoFieldByte1[QChar(91)] = 91-28;
    m_infoFieldByte1[QChar(92)] = 92-28;
    m_infoFieldByte1[QChar(93)] = 93-28;
    m_infoFieldByte1[QChar(94)] = 94-28;
    m_infoFieldByte1[QChar(95)] = 95-28;
    m_infoFieldByte1[QChar(96)] = 96-28;
    m_infoFieldByte1[QChar(97)] = 97-28;
    m_infoFieldByte1[QChar(98)] = 98-28;
    m_infoFieldByte1[QChar(99)] = 99-28;
    m_infoFieldByte1[QChar(100)] = 100-28;
    m_infoFieldByte1[QChar(101)] = 101-28;
    m_infoFieldByte1[QChar(102)] = 102-28;
    m_infoFieldByte1[QChar(103)] = 103-28;
    m_infoFieldByte1[QChar(104)] = 104-28;
    m_infoFieldByte1[QChar(105)] = 105-28;
    m_infoFieldByte1[QChar(106)] = 106-28;
    m_infoFieldByte1[QChar(107)] = 107-28;
    m_infoFieldByte1[QChar(108)] = 108-28;
    m_infoFieldByte1[QChar(109)] = 109-28;
    m_infoFieldByte1[QChar(110)] = 110-28;
    m_infoFieldByte1[QChar(111)] = 111-28;
    m_infoFieldByte1[QChar(112)] = 112-28;
    m_infoFieldByte1[QChar(113)] = 113-28;
    m_infoFieldByte1[QChar(114)] = 114-28;
    m_infoFieldByte1[QChar(115)] = 115-28;
    m_infoFieldByte1[QChar(116)] = 116-28;
    m_infoFieldByte1[QChar(117)] = 117-28;
    m_infoFieldByte1[QChar(118)] = 118-28;
    m_infoFieldByte1[QChar(119)] = 119-28;
    m_infoFieldByte1[QChar(120)] = 120-28;
    m_infoFieldByte1[QChar(121)] = 121-28;
    m_infoFieldByte1[QChar(122)] = 122-28;
    m_infoFieldByte1[QChar(123)] = 123-28;
    m_infoFieldByte1[QChar(124)] = 124-28;
    m_infoFieldByte1[QChar(125)] = 125-28;
    m_infoFieldByte1[QChar(126)] = 126-28;
    m_infoFieldByte1[QChar(127)] = 127-28;
    m_infoFieldByte1[QChar(108)] = 108-8;
    m_infoFieldByte1[QChar(109)] = 109-8;
    m_infoFieldByte1[QChar(110)] = 110-8;
    m_infoFieldByte1[QChar(111)] = 111-8;
    m_infoFieldByte1[QChar(112)] = 112-8;
    m_infoFieldByte1[QChar(113)] = 113-8;
    m_infoFieldByte1[QChar(114)] = 114-8;
    m_infoFieldByte1[QChar(115)] = 115-8;
    m_infoFieldByte1[QChar(116)] = 116-8;
    m_infoFieldByte1[QChar(117)] = 117-8;
    m_infoFieldByte1[QChar(110)] = 110-8;
    m_infoFieldByte1[QChar(111)] = 111-8;
    m_infoFieldByte1[QChar(112)] = 112-8;
    m_infoFieldByte1[QChar(113)] = 113-8;
    m_infoFieldByte1[QChar(114)] = 114-8;
    m_infoFieldByte1[QChar(115)] = 115-8;
    m_infoFieldByte1[QChar(116)] = 116-8;
    m_infoFieldByte1[QChar(117)] = 117-8;
    m_infoFieldByte1[QChar(118)] = 118-8;
    m_infoFieldByte1[QChar(119)] = 119-8;
    m_infoFieldByte1[QChar(120)] = 120-8;
    m_infoFieldByte1[QChar(121)] = 121-8;
    m_infoFieldByte1[QChar(122)] = 122-8;
    m_infoFieldByte1[QChar(123)] = 123-8;
    m_infoFieldByte1[QChar(124)] = 124-8;
    m_infoFieldByte1[QChar(125)] = 125-8;
    m_infoFieldByte1[QChar(126)] = 126-8;
    m_infoFieldByte1[QChar(127)] = 127-8;
    m_infoFieldByte1[QChar(128)] = 128-8;
    m_infoFieldByte1[QChar(129)] = 129-8;
    m_infoFieldByte1[QChar(130)] = 130-8;
    m_infoFieldByte1[QChar(131)] = 131-8;
    m_infoFieldByte1[QChar(132)] = 132-8;
    m_infoFieldByte1[QChar(133)] = 133-8;
    m_infoFieldByte1[QChar(134)] = 134-8;
    m_infoFieldByte1[QChar(135)] = 135-8;
    m_infoFieldByte1[QChar(136)] = 136-8;
    m_infoFieldByte1[QChar(137)] = 137-8;
    m_infoFieldByte1[QChar(138)] = 138-8;
    m_infoFieldByte1[QChar(139)] = 139-8;
    m_infoFieldByte1[QChar(140)] = 140-8;
    m_infoFieldByte1[QChar(141)] = 141-8;
    m_infoFieldByte1[QChar(142)] = 142-8;
    m_infoFieldByte1[QChar(143)] = 143-8;
    m_infoFieldByte1[QChar(144)] = 144-8;
    m_infoFieldByte1[QChar(145)] = 145-8;
    m_infoFieldByte1[QChar(146)] = 146-8;
    m_infoFieldByte1[QChar(147)] = 147-8;
    m_infoFieldByte1[QChar(148)] = 148-8;
    m_infoFieldByte1[QChar(149)] = 149-8;
    m_infoFieldByte1[QChar(150)] = 150-8;
    m_infoFieldByte1[QChar(151)] = 151-8;
    m_infoFieldByte1[QChar(152)] = 152-8;
    m_infoFieldByte1[QChar(153)] = 153-8;
    m_infoFieldByte1[QChar(154)] = 154-8;
    m_infoFieldByte1[QChar(155)] = 155-8;
    m_infoFieldByte1[QChar(156)] = 156-8;
    m_infoFieldByte1[QChar(157)] = 157-8;
    m_infoFieldByte1[QChar(158)] = 158-8;
    m_infoFieldByte1[QChar(159)] = 159-8;
    m_infoFieldByte1[QChar(160)] = 160-8;
    m_infoFieldByte1[QChar(161)] = 161-8;
    m_infoFieldByte1[QChar(162)] = 162-8;
    m_infoFieldByte1[QChar(163)] = 163-8;
    m_infoFieldByte1[QChar(164)] = 164-8;
    m_infoFieldByte1[QChar(165)] = 165-8;
    m_infoFieldByte1[QChar(166)] = 166-8;
    m_infoFieldByte1[QChar(167)] = 167-8;
    m_infoFieldByte1[QChar(168)] = 168-8;
    m_infoFieldByte1[QChar(169)] = 169-8;
    m_infoFieldByte1[QChar(170)] = 170-8;
    m_infoFieldByte1[QChar(171)] = 171-8;
    m_infoFieldByte1[QChar(172)] = 172-8;
    m_infoFieldByte1[QChar(173)] = 173-8;
    m_infoFieldByte1[QChar(174)] = 174-8;
    m_infoFieldByte1[QChar(175)] = 175-8;
    m_infoFieldByte1[QChar(176)] = 176-8;
    m_infoFieldByte1[QChar(177)] = 177-8;
    m_infoFieldByte1[QChar(178)] = 178-8;
    m_infoFieldByte1[QChar(179)] = 179-8;


    m_standardMessageText[0] = "M0: Off Duty";
    m_standardMessageText[1] = "M1: En Route";
    m_standardMessageText[2] = "M2: In Service";
    m_standardMessageText[3] = "M3: Returning";
    m_standardMessageText[4] = "M4: Committed";
    m_standardMessageText[5] = "M5: Special";
    m_standardMessageText[6] = "M6: Priority";
    m_standardMessageText[7] = "M7: EMERGENCY";

    m_customMessageText[0] = "Custom-0";
    m_customMessageText[1] = "Custom-1";
    m_customMessageText[2] = "Custom-2";
    m_customMessageText[3] = "Custom-3";
    m_customMessageText[4] = "Custom-4";
    m_customMessageText[5] = "Custom-5";
    m_customMessageText[6] = "Custom-6";
    m_customMessageText[7] = "Custom-7";
    m_customMessageText[7] = "M7: EMERGENCY";

    m_pixmaps[QPair<QChar, QChar>('/','!')] = "aprs/primary/00.png";
    m_pixmaps[QPair<QChar, QChar>('\\','!')] = "aprs/secondary/00.png";
    m_pixmaps[QPair<QChar, QChar>('/','"')] = "aprs/primary/01.png";
    m_pixmaps[QPair<QChar, QChar>('\\','"')] = "aprs/secondary/01.png";
    m_pixmaps[QPair<QChar, QChar>('/','#')] = "aprs/primary/02.png";
    m_pixmaps[QPair<QChar, QChar>('\\','#')] = "aprs/secondary/02.png";
    m_pixmaps[QPair<QChar, QChar>('/','$')] = "aprs/primary/03.png";
    m_pixmaps[QPair<QChar, QChar>('\\','$')] = "aprs/secondary/03.png";
    m_pixmaps[QPair<QChar, QChar>('/','%')] = "aprs/primary/04.png";
    m_pixmaps[QPair<QChar, QChar>('\\','%')] = "aprs/secondary/04.png";
    m_pixmaps[QPair<QChar, QChar>('/','&')] = "aprs/primary/05.png";
    m_pixmaps[QPair<QChar, QChar>('\\','&')] = "aprs/secondary/05.png";
    m_pixmaps[QPair<QChar, QChar>('/','\'')] = "aprs/primary/06.png";
    m_pixmaps[QPair<QChar, QChar>('\\','\'')] = "aprs/secondary/06.png";
    m_pixmaps[QPair<QChar, QChar>('/','(')] = "aprs/primary/07.png";
    m_pixmaps[QPair<QChar, QChar>('\\','(')] = "aprs/secondary/07.png";
    m_pixmaps[QPair<QChar, QChar>('/',')')] = "aprs/primary/08.png";
    m_pixmaps[QPair<QChar, QChar>('\\',')')] = "aprs/secondary/08.png";
    m_pixmaps[QPair<QChar, QChar>('/','*')] = "aprs/primary/09.png";
    m_pixmaps[QPair<QChar, QChar>('\\','*')] = "aprs/secondary/09.png";
    m_pixmaps[QPair<QChar, QChar>('/','+')] = "aprs/primary/10.png";
    m_pixmaps[QPair<QChar, QChar>('\\','+')] = "aprs/secondary/10.png";
    m_pixmaps[QPair<QChar, QChar>('/',',')] = "aprs/primary/11.png";
    m_pixmaps[QPair<QChar, QChar>('\\',',')] = "aprs/secondary/11.png";
    m_pixmaps[QPair<QChar, QChar>('/','-')] = "aprs/primary/12.png";
    m_pixmaps[QPair<QChar, QChar>('\\','-')] = "aprs/secondary/12.png";
    m_pixmaps[QPair<QChar, QChar>('/','.')] = "aprs/primary/13.png";
    m_pixmaps[QPair<QChar, QChar>('\\','.')] = "aprs/secondary/13.png";
    m_pixmaps[QPair<QChar, QChar>('/','/')] = "aprs/primary/14.png";
    m_pixmaps[QPair<QChar, QChar>('\\','/')] = "aprs/secondary/14.png";
    m_pixmaps[QPair<QChar, QChar>('/','0')] = "aprs/primary/15.png";
    m_pixmaps[QPair<QChar, QChar>('\\','0')] = "aprs/secondary/15.png";
    m_pixmaps[QPair<QChar, QChar>('/','1')] = "aprs/primary/16.png";
    m_pixmaps[QPair<QChar, QChar>('\\','1')] = "aprs/secondary/16.png";
    m_pixmaps[QPair<QChar, QChar>('/','2')] = "aprs/primary/17.png";
    m_pixmaps[QPair<QChar, QChar>('\\','2')] = "aprs/secondary/17.png";
    m_pixmaps[QPair<QChar, QChar>('/','3')] = "aprs/primary/18.png";
    m_pixmaps[QPair<QChar, QChar>('\\','3')] = "aprs/secondary/18.png";
    m_pixmaps[QPair<QChar, QChar>('/','4')] = "aprs/primary/19.png";
    m_pixmaps[QPair<QChar, QChar>('\\','4')] = "aprs/secondary/19.png";
    m_pixmaps[QPair<QChar, QChar>('/','5')] = "aprs/primary/20.png";
    m_pixmaps[QPair<QChar, QChar>('\\','5')] = "aprs/secondary/20.png";
    m_pixmaps[QPair<QChar, QChar>('/','6')] = "aprs/primary/21.png";
    m_pixmaps[QPair<QChar, QChar>('\\','6')] = "aprs/secondary/21.png";
    m_pixmaps[QPair<QChar, QChar>('/','7')] = "aprs/primary/22.png";
    m_pixmaps[QPair<QChar, QChar>('\\','7')] = "aprs/secondary/22.png";
    m_pixmaps[QPair<QChar, QChar>('/','8')] = "aprs/primary/23.png";
    m_pixmaps[QPair<QChar, QChar>('\\','8')] = "aprs/secondary/23.png";
    m_pixmaps[QPair<QChar, QChar>('/','9')] = "aprs/primary/24.png";
    m_pixmaps[QPair<QChar, QChar>('\\','9')] = "aprs/secondary/24.png";
    m_pixmaps[QPair<QChar, QChar>('/',':')] = "aprs/primary/25.png";
    m_pixmaps[QPair<QChar, QChar>('\\',':')] = "aprs/secondary/25.png";
    m_pixmaps[QPair<QChar, QChar>('/',';')] = "aprs/primary/26.png";
    m_pixmaps[QPair<QChar, QChar>('\\',';')] = "aprs/secondary/26.png";
    m_pixmaps[QPair<QChar, QChar>('/','<')] = "aprs/primary/27.png";
    m_pixmaps[QPair<QChar, QChar>('\\','<')] = "aprs/secondary/27.png";
    m_pixmaps[QPair<QChar, QChar>('/','=')] = "aprs/primary/28.png";
    m_pixmaps[QPair<QChar, QChar>('\\','=')] = "aprs/secondary/28.png";
    m_pixmaps[QPair<QChar, QChar>('/','>')] = "aprs/primary/29.png";
    m_pixmaps[QPair<QChar, QChar>('\\','>')] = "aprs/secondary/29.png";
    m_pixmaps[QPair<QChar, QChar>('/','?')] = "aprs/primary/30.png";
    m_pixmaps[QPair<QChar, QChar>('\\','?')] = "aprs/secondary/30.png";
    m_pixmaps[QPair<QChar, QChar>('/','@')] = "aprs/primary/31.png";
    m_pixmaps[QPair<QChar, QChar>('\\','@')] = "aprs/secondary/31.png";
    m_pixmaps[QPair<QChar, QChar>('/','A')] = "aprs/primary/32.png";
    m_pixmaps[QPair<QChar, QChar>('\\','A')] = "aprs/secondary/32.png";
    m_pixmaps[QPair<QChar, QChar>('/','B')] = "aprs/primary/33.png";
    m_pixmaps[QPair<QChar, QChar>('\\','B')] = "aprs/secondary/33.png";
    m_pixmaps[QPair<QChar, QChar>('/','C')] = "aprs/primary/34.png";
    m_pixmaps[QPair<QChar, QChar>('\\','C')] = "aprs/secondary/34.png";
    m_pixmaps[QPair<QChar, QChar>('/','D')] = "aprs/primary/35.png";
    m_pixmaps[QPair<QChar, QChar>('\\','D')] = "aprs/secondary/35.png";
    m_pixmaps[QPair<QChar, QChar>('/','E')] = "aprs/primary/36.png";
    m_pixmaps[QPair<QChar, QChar>('\\','E')] = "aprs/secondary/36.png";
    m_pixmaps[QPair<QChar, QChar>('/','F')] = "aprs/primary/37.png";
    m_pixmaps[QPair<QChar, QChar>('\\','F')] = "aprs/secondary/37.png";
    m_pixmaps[QPair<QChar, QChar>('/','G')] = "aprs/primary/38.png";
    m_pixmaps[QPair<QChar, QChar>('\\','G')] = "aprs/secondary/38.png";
    m_pixmaps[QPair<QChar, QChar>('/','H')] = "aprs/primary/39.png";
    m_pixmaps[QPair<QChar, QChar>('\\','H')] = "aprs/secondary/39.png";
    m_pixmaps[QPair<QChar, QChar>('/','I')] = "aprs/primary/40.png";
    m_pixmaps[QPair<QChar, QChar>('\\','I')] = "aprs/secondary/40.png";
    m_pixmaps[QPair<QChar, QChar>('/','J')] = "aprs/primary/41.png";
    m_pixmaps[QPair<QChar, QChar>('\\','J')] = "aprs/secondary/41.png";
    m_pixmaps[QPair<QChar, QChar>('/','K')] = "aprs/primary/42.png";
    m_pixmaps[QPair<QChar, QChar>('\\','K')] = "aprs/secondary/42.png";
    m_pixmaps[QPair<QChar, QChar>('/','L')] = "aprs/primary/43.png";
    m_pixmaps[QPair<QChar, QChar>('\\','L')] = "aprs/secondary/43.png";
    m_pixmaps[QPair<QChar, QChar>('/','M')] = "aprs/primary/44.png";
    m_pixmaps[QPair<QChar, QChar>('\\','M')] = "aprs/secondary/44.png";
    m_pixmaps[QPair<QChar, QChar>('/','N')] = "aprs/primary/45.png";
    m_pixmaps[QPair<QChar, QChar>('\\','N')] = "aprs/secondary/45.png";
    m_pixmaps[QPair<QChar, QChar>('/','O')] = "aprs/primary/46.png";
    m_pixmaps[QPair<QChar, QChar>('\\','O')] = "aprs/secondary/46.png";
    m_pixmaps[QPair<QChar, QChar>('/','P')] = "aprs/primary/47.png";
    m_pixmaps[QPair<QChar, QChar>('\\','P')] = "aprs/secondary/47.png";
    m_pixmaps[QPair<QChar, QChar>('/','Q')] = "aprs/primary/48.png";
    m_pixmaps[QPair<QChar, QChar>('\\','Q')] = "aprs/secondary/48.png";
    m_pixmaps[QPair<QChar, QChar>('/','R')] = "aprs/primary/49.png";
    m_pixmaps[QPair<QChar, QChar>('\\','R')] = "aprs/secondary/49.png";
    m_pixmaps[QPair<QChar, QChar>('/','S')] = "aprs/primary/50.png";
    m_pixmaps[QPair<QChar, QChar>('\\','S')] = "aprs/secondary/50.png";
    m_pixmaps[QPair<QChar, QChar>('/','T')] = "aprs/primary/51.png";
    m_pixmaps[QPair<QChar, QChar>('\\','T')] = "aprs/secondary/51.png";
    m_pixmaps[QPair<QChar, QChar>('/','U')] = "aprs/primary/52.png";
    m_pixmaps[QPair<QChar, QChar>('\\','U')] = "aprs/secondary/52.png";
    m_pixmaps[QPair<QChar, QChar>('/','V')] = "aprs/primary/53.png";
    m_pixmaps[QPair<QChar, QChar>('\\','V')] = "aprs/secondary/53.png";
    m_pixmaps[QPair<QChar, QChar>('/','W')] = "aprs/primary/54.png";
    m_pixmaps[QPair<QChar, QChar>('\\','W')] = "aprs/secondary/54.png";
    m_pixmaps[QPair<QChar, QChar>('/','X')] = "aprs/primary/55.png";
    m_pixmaps[QPair<QChar, QChar>('\\','X')] = "aprs/secondary/55.png";
    m_pixmaps[QPair<QChar, QChar>('/','Y')] = "aprs/primary/56.png";
    m_pixmaps[QPair<QChar, QChar>('\\','Y')] = "aprs/secondary/56.png";
    m_pixmaps[QPair<QChar, QChar>('/','Z')] = "aprs/primary/57.png";
    m_pixmaps[QPair<QChar, QChar>('\\','Z')] = "aprs/secondary/57.png";
    m_pixmaps[QPair<QChar, QChar>('/','[')] = "aprs/primary/58.png";
    m_pixmaps[QPair<QChar, QChar>('\\','[')] = "aprs/secondary/58.png";
    m_pixmaps[QPair<QChar, QChar>('/','\\')] = "aprs/primary/59.png";
    m_pixmaps[QPair<QChar, QChar>('\\','\\')] = "aprs/secondary/59.png";
    m_pixmaps[QPair<QChar, QChar>('/',']')] = "aprs/primary/60.png";
    m_pixmaps[QPair<QChar, QChar>('\\',']')] = "aprs/secondary/60.png";
    m_pixmaps[QPair<QChar, QChar>('/','^')] = "aprs/primary/61.png";
    m_pixmaps[QPair<QChar, QChar>('\\','^')] = "aprs/secondary/61.png";
    m_pixmaps[QPair<QChar, QChar>('/','_')] = "aprs/primary/62.png";
    m_pixmaps[QPair<QChar, QChar>('\\','_')] = "aprs/secondary/62.png";
    m_pixmaps[QPair<QChar, QChar>('/','`')] = "aprs/primary/63.png";
    m_pixmaps[QPair<QChar, QChar>('\\','`')] = "aprs/secondary/63.png";
    m_pixmaps[QPair<QChar, QChar>('/','a')] = "aprs/primary/64.png";
    m_pixmaps[QPair<QChar, QChar>('\\','a')] = "aprs/secondary/64.png";
    m_pixmaps[QPair<QChar, QChar>('/','b')] = "aprs/primary/65.png";
    m_pixmaps[QPair<QChar, QChar>('\\','b')] = "aprs/secondary/65.png";
    m_pixmaps[QPair<QChar, QChar>('/','c')] = "aprs/primary/66.png";
    m_pixmaps[QPair<QChar, QChar>('\\','c')] = "aprs/secondary/66.png";
    m_pixmaps[QPair<QChar, QChar>('/','d')] = "aprs/primary/67.png";
    m_pixmaps[QPair<QChar, QChar>('\\','d')] = "aprs/secondary/67.png";
    m_pixmaps[QPair<QChar, QChar>('/','e')] = "aprs/primary/68.png";
    m_pixmaps[QPair<QChar, QChar>('\\','e')] = "aprs/secondary/68.png";
    m_pixmaps[QPair<QChar, QChar>('/','f')] = "aprs/primary/69.png";
    m_pixmaps[QPair<QChar, QChar>('\\','f')] = "aprs/secondary/69.png";
    m_pixmaps[QPair<QChar, QChar>('/','g')] = "aprs/primary/70.png";
    m_pixmaps[QPair<QChar, QChar>('\\','g')] = "aprs/secondary/70.png";
    m_pixmaps[QPair<QChar, QChar>('/','h')] = "aprs/primary/71.png";
    m_pixmaps[QPair<QChar, QChar>('\\','h')] = "aprs/secondary/71.png";
    m_pixmaps[QPair<QChar, QChar>('/','i')] = "aprs/primary/72.png";
    m_pixmaps[QPair<QChar, QChar>('\\','i')] = "aprs/secondary/72.png";
    m_pixmaps[QPair<QChar, QChar>('/','j')] = "aprs/primary/73.png";
    m_pixmaps[QPair<QChar, QChar>('\\','j')] = "aprs/secondary/73.png";
    m_pixmaps[QPair<QChar, QChar>('/','k')] = "aprs/primary/74.png";
    m_pixmaps[QPair<QChar, QChar>('\\','k')] = "aprs/secondary/74.png";
    m_pixmaps[QPair<QChar, QChar>('/','l')] = "aprs/primary/75.png";
    m_pixmaps[QPair<QChar, QChar>('\\','l')] = "aprs/secondary/75.png";
    m_pixmaps[QPair<QChar, QChar>('/','m')] = "aprs/primary/76.png";
    m_pixmaps[QPair<QChar, QChar>('\\','m')] = "aprs/secondary/76.png";
    m_pixmaps[QPair<QChar, QChar>('/','n')] = "aprs/primary/77.png";
    m_pixmaps[QPair<QChar, QChar>('\\','n')] = "aprs/secondary/77.png";
    m_pixmaps[QPair<QChar, QChar>('/','o')] = "aprs/primary/78.png";
    m_pixmaps[QPair<QChar, QChar>('\\','o')] = "aprs/secondary/78.png";
    m_pixmaps[QPair<QChar, QChar>('/','p')] = "aprs/primary/79.png";
    m_pixmaps[QPair<QChar, QChar>('\\','p')] = "aprs/secondary/79.png";
    m_pixmaps[QPair<QChar, QChar>('/','q')] = "aprs/primary/80.png";
    m_pixmaps[QPair<QChar, QChar>('\\','q')] = "aprs/secondary/80.png";
    m_pixmaps[QPair<QChar, QChar>('/','r')] = "aprs/primary/81.png";
    m_pixmaps[QPair<QChar, QChar>('\\','r')] = "aprs/secondary/81.png";
    m_pixmaps[QPair<QChar, QChar>('/','s')] = "aprs/primary/82.png";
    m_pixmaps[QPair<QChar, QChar>('\\','s')] = "aprs/secondary/82.png";
    m_pixmaps[QPair<QChar, QChar>('/','t')] = "aprs/primary/83.png";
    m_pixmaps[QPair<QChar, QChar>('\\','t')] = "aprs/secondary/83.png";
    m_pixmaps[QPair<QChar, QChar>('/','u')] = "aprs/primary/84.png";
    m_pixmaps[QPair<QChar, QChar>('\\','u')] = "aprs/secondary/84.png";
    m_pixmaps[QPair<QChar, QChar>('/','v')] = "aprs/primary/85.png";
    m_pixmaps[QPair<QChar, QChar>('\\','v')] = "aprs/secondary/85.png";
    m_pixmaps[QPair<QChar, QChar>('/','w')] = "aprs/primary/86.png";
    m_pixmaps[QPair<QChar, QChar>('\\','w')] = "aprs/secondary/86.png";
    m_pixmaps[QPair<QChar, QChar>('/','x')] = "aprs/primary/87.png";
    m_pixmaps[QPair<QChar, QChar>('\\','x')] = "aprs/secondary/87.png";
    m_pixmaps[QPair<QChar, QChar>('/','y')] = "aprs/primary/88.png";
    m_pixmaps[QPair<QChar, QChar>('\\','y')] = "aprs/secondary/88.png";
    m_pixmaps[QPair<QChar, QChar>('/','z')] = "aprs/primary/89.png";
    m_pixmaps[QPair<QChar, QChar>('\\','z')] = "aprs/secondary/89.png";
    m_pixmaps[QPair<QChar, QChar>('/','{')] = "aprs/primary/90.png";
    m_pixmaps[QPair<QChar, QChar>('\\','{')] = "aprs/secondary/90.png";
    m_pixmaps[QPair<QChar, QChar>('/','|')] = "aprs/primary/91.png";
    m_pixmaps[QPair<QChar, QChar>('\\','|')] = "aprs/secondary/91.png";
    m_pixmaps[QPair<QChar, QChar>('/','}')] = "aprs/primary/92.png";
    m_pixmaps[QPair<QChar, QChar>('\\','}')] = "aprs/secondary/92.png";
    m_pixmaps[QPair<QChar, QChar>('/','~')] = "aprs/primary/93.png";
    m_pixmaps[QPair<QChar, QChar>('\\','~')] = "aprs/secondary/93.png";
}
