/****************************************************************************
** Meta object code from reading C++ file 'CurrentLocationWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/CurrentLocationWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CurrentLocationWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::CurrentLocationWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::CurrentLocationWidget",
        "setRecenterMode",
        "",
        "recenterMode",
        "setAutoZoom",
        "activate",
        "setTrackVisible",
        "visible",
        "setLastOpenPath",
        "path",
        "setLastSavePath",
        "changePositionProvider",
        "index",
        "trackPlacemark",
        "receiveGpsCoordinates",
        "GeoDataCoordinates",
        "in",
        "speed",
        "adjustPositionTrackingStatus",
        "PositionProviderStatus",
        "status",
        "centerOnCurrentLocation",
        "updateRecenterComboBox",
        "AutoNavigation::CenterMode",
        "centerMode",
        "updateAutoZoomCheckBox",
        "autoZoom",
        "updateActivePositionProvider",
        "PositionProviderPlugin*",
        "updateGuidanceMode",
        "saveTrack",
        "openTrack",
        "clearTrack"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setRecenterMode'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setAutoZoom'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setTrackVisible'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'setLastOpenPath'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'setLastSavePath'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'changePositionProvider'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'trackPlacemark'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'receiveGpsCoordinates'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &, qreal)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'adjustPositionTrackingStatus'
        QtMocHelpers::SlotData<void(PositionProviderStatus)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'centerOnCurrentLocation'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRecenterComboBox'
        QtMocHelpers::SlotData<void(AutoNavigation::CenterMode)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'updateAutoZoomCheckBox'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'updateActivePositionProvider'
        QtMocHelpers::SlotData<void(PositionProviderPlugin *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'updateGuidanceMode'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveTrack'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openTrack'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearTrack'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CurrentLocationWidget, qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::CurrentLocationWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::CurrentLocationWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CurrentLocationWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setRecenterMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->setAutoZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->setTrackVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setLastOpenPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setLastSavePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->changePositionProvider((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->trackPlacemark(); break;
        case 7: _t->d->receiveGpsCoordinates((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 8: _t->d->adjustPositionTrackingStatus((*reinterpret_cast<std::add_pointer_t<PositionProviderStatus>>(_a[1]))); break;
        case 9: _t->d->centerOnCurrentLocation(); break;
        case 10: _t->d->updateRecenterComboBox((*reinterpret_cast<std::add_pointer_t<AutoNavigation::CenterMode>>(_a[1]))); break;
        case 11: _t->d->updateAutoZoomCheckBox((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->d->updateActivePositionProvider((*reinterpret_cast<std::add_pointer_t<PositionProviderPlugin*>>(_a[1]))); break;
        case 13: _t->d->updateGuidanceMode(); break;
        case 14: _t->d->saveTrack(); break;
        case 15: _t->d->openTrack(); break;
        case 16: _t->d->clearTrack(); break;
        default: ;
        }
    }
}

const QMetaObject *Marble::CurrentLocationWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::CurrentLocationWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble21CurrentLocationWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::CurrentLocationWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
