/********************************************************************************
** Form generated from reading UI file 'CycleStreetsConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CYCLESTREETSCONFIGWIDGET_H
#define UI_CYCLESTREETSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CycleStreetsConfigWidget
{
public:
    QFormLayout *formLayout;
    QLabel *planLabel;
    QComboBox *plan;
    QLabel *speedLabel;
    QComboBox *speed;

    void setupUi(QWidget *CycleStreetsConfigWidget)
    {
        if (CycleStreetsConfigWidget->objectName().isEmpty())
            CycleStreetsConfigWidget->setObjectName("CycleStreetsConfigWidget");
        CycleStreetsConfigWidget->resize(168, 58);
        formLayout = new QFormLayout(CycleStreetsConfigWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        planLabel = new QLabel(CycleStreetsConfigWidget);
        planLabel->setObjectName("planLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, planLabel);

        plan = new QComboBox(CycleStreetsConfigWidget);
        plan->setObjectName("plan");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, plan);

        speedLabel = new QLabel(CycleStreetsConfigWidget);
        speedLabel->setObjectName("speedLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, speedLabel);

        speed = new QComboBox(CycleStreetsConfigWidget);
        speed->setObjectName("speed");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, speed);


        retranslateUi(CycleStreetsConfigWidget);

        QMetaObject::connectSlotsByName(CycleStreetsConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *CycleStreetsConfigWidget)
    {
        planLabel->setText(QCoreApplication::translate("CycleStreetsConfigWidget", "Route type:", nullptr));
        speedLabel->setText(QCoreApplication::translate("CycleStreetsConfigWidget", "Speed:", nullptr));
        (void)CycleStreetsConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class CycleStreetsConfigWidget: public Ui_CycleStreetsConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CYCLESTREETSCONFIGWIDGET_H
