/****************************************************************************
** Meta object code from reading C++ file 'MapViewWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/MapViewWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MapViewWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble13MapViewWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MapViewWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble13MapViewWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MapViewWidget",
        "celestialBodyChanged",
        "",
        "mapThemeIdChanged",
        "projectionChanged",
        "Projection",
        "showMapWizard",
        "mapThemeDeleted",
        "setMapThemeId",
        "setProjection",
        "projection",
        "globeViewRequested",
        "mercatorViewRequested",
        "flatViewRequested",
        "gnomonicViewRequested",
        "stereographicViewRequested",
        "lambertAzimuthalViewRequested",
        "azimuthalEquidistantViewRequested",
        "verticalPerspectiveViewRequested",
        "celestialBodySelected",
        "comboIndex",
        "projectionSelected",
        "projectionIndex",
        "mapThemeSelected",
        "QModelIndex",
        "index",
        "showContextMenu",
        "QPoint",
        "pos",
        "deleteMap",
        "toggleFavorite",
        "toggleIconSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'celestialBodyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'mapThemeIdChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'projectionChanged'
        QtMocHelpers::SignalData<void(Projection)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'showMapWizard'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapThemeDeleted'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMapThemeId'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setProjection'
        QtMocHelpers::SlotData<void(Projection)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 10 },
        }}),
        // Slot 'globeViewRequested'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mercatorViewRequested'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'flatViewRequested'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gnomonicViewRequested'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stereographicViewRequested'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lambertAzimuthalViewRequested'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'azimuthalEquidistantViewRequested'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'verticalPerspectiveViewRequested'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'celestialBodySelected'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'projectionSelected'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'mapThemeSelected'
        QtMocHelpers::SlotData<void(QModelIndex)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'mapThemeSelected'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'deleteMap'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFavorite'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleIconSize'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MapViewWidget, qt_meta_tag_ZN6Marble13MapViewWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MapViewWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13MapViewWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13MapViewWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble13MapViewWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::MapViewWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MapViewWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->celestialBodyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->mapThemeIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->projectionChanged((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 3: _t->showMapWizard(); break;
        case 4: _t->mapThemeDeleted(); break;
        case 5: _t->setMapThemeId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setProjection((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 7: _t->globeViewRequested(); break;
        case 8: _t->mercatorViewRequested(); break;
        case 9: _t->flatViewRequested(); break;
        case 10: _t->gnomonicViewRequested(); break;
        case 11: _t->stereographicViewRequested(); break;
        case 12: _t->lambertAzimuthalViewRequested(); break;
        case 13: _t->azimuthalEquidistantViewRequested(); break;
        case 14: _t->verticalPerspectiveViewRequested(); break;
        case 15: _t->d->celestialBodySelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->d->projectionSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->d->mapThemeSelected((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 18: _t->d->mapThemeSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->d->showContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 20: _t->d->deleteMap(); break;
        case 21: _t->d->toggleFavorite(); break;
        case 22: _t->d->toggleIconSize(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MapViewWidget::*)(const QString & )>(_a, &MapViewWidget::celestialBodyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MapViewWidget::*)(const QString & )>(_a, &MapViewWidget::mapThemeIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MapViewWidget::*)(Projection )>(_a, &MapViewWidget::projectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MapViewWidget::*)()>(_a, &MapViewWidget::showMapWizard, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MapViewWidget::*)()>(_a, &MapViewWidget::mapThemeDeleted, 4))
            return;
    }
}

const QMetaObject *Marble::MapViewWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MapViewWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13MapViewWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::MapViewWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Marble::MapViewWidget::celestialBodyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::MapViewWidget::mapThemeIdChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::MapViewWidget::projectionChanged(Projection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::MapViewWidget::showMapWizard()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::MapViewWidget::mapThemeDeleted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
