/********************************************************************************
** Form generated from reading UI file 'CrosshairsConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CROSSHAIRSCONFIGWIDGET_H
#define UI_CROSSHAIRSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CrosshairsConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QListWidget *m_themeList;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *CrosshairsConfigWidget)
    {
        if (CrosshairsConfigWidget->objectName().isEmpty())
            CrosshairsConfigWidget->setObjectName("CrosshairsConfigWidget");
        CrosshairsConfigWidget->resize(318, 136);
        verticalLayout_3 = new QVBoxLayout(CrosshairsConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label = new QLabel(CrosshairsConfigWidget);
        label->setObjectName("label");

        verticalLayout_3->addWidget(label);

        m_themeList = new QListWidget(CrosshairsConfigWidget);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/crosshairs-darkened.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(m_themeList);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/crosshairs-gun1.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/crosshairs-gun2.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/crosshairs-circled.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/crosshairs-german.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem4->setIcon(icon4);
        m_themeList->setObjectName("m_themeList");
        m_themeList->setIconSize(QSize(21, 21));
        m_themeList->setFlow(QListView::LeftToRight);
        m_themeList->setResizeMode(QListView::Adjust);
        m_themeList->setViewMode(QListView::IconMode);

        verticalLayout_3->addWidget(m_themeList);

        m_buttonBox = new QDialogButtonBox(CrosshairsConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(m_buttonBox);


        retranslateUi(CrosshairsConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, CrosshairsConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, CrosshairsConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CrosshairsConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *CrosshairsConfigWidget)
    {
        CrosshairsConfigWidget->setWindowTitle(QCoreApplication::translate("CrosshairsConfigWidget", "Configure Crosshairs Plugin", nullptr));
        label->setText(QCoreApplication::translate("CrosshairsConfigWidget", "Theme", nullptr));

        const bool __sortingEnabled = m_themeList->isSortingEnabled();
        m_themeList->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = m_themeList->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("CrosshairsConfigWidget", "Default", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = m_themeList->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("CrosshairsConfigWidget", "Gun 1", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = m_themeList->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("CrosshairsConfigWidget", "Gun 2", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = m_themeList->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("CrosshairsConfigWidget", "Circled", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = m_themeList->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("CrosshairsConfigWidget", "German", nullptr));
        m_themeList->setSortingEnabled(__sortingEnabled);

    } // retranslateUi

};

namespace Ui {
    class CrosshairsConfigWidget: public Ui_CrosshairsConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CROSSHAIRSCONFIGWIDGET_H
