/****************************************************************************
** Meta object code from reading C++ file 'AbstractDataPluginModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/lib/marble/AbstractDataPluginModel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractDataPluginModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::AbstractDataPluginModel::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::AbstractDataPluginModel",
        "itemsUpdated",
        "",
        "favoriteItemsChanged",
        "favoriteItems",
        "favoriteItemsOnlyChanged",
        "addItemsToList",
        "QList<AbstractDataPluginItem*>",
        "items",
        "addItemToList",
        "AbstractDataPluginItem*",
        "item",
        "clear",
        "handleChangedViewport",
        "processFinishedJob",
        "relativeUrlString",
        "id",
        "removeItem",
        "favoriteItemChanged",
        "isFavorite",
        "scheduleItemSort",
        "themeChanged",
        "favoritesModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemsUpdated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoriteItemsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'favoriteItemsOnlyChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addItemsToList'
        QtMocHelpers::SlotData<void(const QList<AbstractDataPluginItem*> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'addItemToList'
        QtMocHelpers::SlotData<void(AbstractDataPluginItem *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleChangedViewport'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processFinishedJob'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'removeItem'
        QtMocHelpers::SlotData<void(QObject *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 11 },
        }}),
        // Slot 'favoriteItemChanged'
        QtMocHelpers::SlotData<void(const QString &, bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'scheduleItemSort'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'themeChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'favoritesModel'
        QtMocHelpers::PropertyData<QObject*>(22, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractDataPluginModel, qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::AbstractDataPluginModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t>.metaTypes,
    nullptr
} };

void Marble::AbstractDataPluginModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractDataPluginModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemsUpdated(); break;
        case 1: _t->favoriteItemsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->favoriteItemsOnlyChanged(); break;
        case 3: _t->addItemsToList((*reinterpret_cast<std::add_pointer_t<QList<AbstractDataPluginItem*>>>(_a[1]))); break;
        case 4: _t->addItemToList((*reinterpret_cast<std::add_pointer_t<AbstractDataPluginItem*>>(_a[1]))); break;
        case 5: _t->clear(); break;
        case 6: _t->handleChangedViewport(); break;
        case 7: _t->processFinishedJob((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->removeItem((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 9: _t->favoriteItemChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->scheduleItemSort(); break;
        case 11: _t->themeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractDataPluginModel::*)()>(_a, &AbstractDataPluginModel::itemsUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractDataPluginModel::*)(const QStringList & )>(_a, &AbstractDataPluginModel::favoriteItemsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractDataPluginModel::*)()>(_a, &AbstractDataPluginModel::favoriteItemsOnlyChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->favoritesModel(); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::AbstractDataPluginModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::AbstractDataPluginModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble23AbstractDataPluginModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::AbstractDataPluginModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Marble::AbstractDataPluginModel::itemsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::AbstractDataPluginModel::favoriteItemsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::AbstractDataPluginModel::favoriteItemsOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
