/****************************************************************************
** Meta object code from reading C++ file 'QtMainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.1/src/apps/marble-qt/QtMainWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QtMainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MainWindow",
        "showPosition",
        "",
        "position",
        "showDistance",
        "showZoom",
        "showDateTime",
        "initObject",
        "QVariantMap",
        "cmdLineSettings",
        "editSettings",
        "updateSettings",
        "fallBackToDefaultTheme",
        "changeRecordingState",
        "updateWindowTitle",
        "updateCenterFromTheme",
        "openFile",
        "openMapDialog",
        "exportMapScreenShot",
        "showDownloadRegionDialog",
        "printMapScreenShot",
        "workOffline",
        "showMapWizard",
        "copyMap",
        "copyCoordinates",
        "updateMapEditButtonVisibility",
        "mapTheme",
        "showMovieCaptureDialog",
        "stopRecording",
        "lockPosition",
        "createPluginsMenus",
        "createPluginMenus",
        "showClouds",
        "controlSun",
        "controlTime",
        "showSun",
        "reload",
        "changeViewSize",
        "QAction*",
        "showFullScreen",
        "showStatusBar",
        "setupStatusBar",
        "setupDownloadProgressBar",
        "enterWhatsThis",
        "aboutMarble",
        "handbook",
        "openForum",
        "openEditBookmarkDialog",
        "setHome",
        "createBookmarksListMenu",
        "QMenu*",
        "bookmarksListMenu",
        "const GeoDataContainer*",
        "container",
        "lookAtBookmark",
        "action",
        "manageBookmarks",
        "createBookmarkMenu",
        "createFolderList",
        "showBookmarks",
        "show",
        "downloadRegion",
        "showZoomLevel",
        "changeAngleDisplayUnit",
        "handleProgress",
        "removeProgressItem"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showPosition'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'showDistance'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'showZoom'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'showDateTime'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initObject'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'editSettings'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSettings'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fallBackToDefaultTheme'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeRecordingState'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowTitle'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCenterFromTheme'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openMapDialog'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportMapScreenShot'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDownloadRegionDialog'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'printMapScreenShot'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'workOffline'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showMapWizard'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyMap'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyCoordinates'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMapEditButtonVisibility'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'showMovieCaptureDialog'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopRecording'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lockPosition'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'createPluginsMenus'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createPluginMenus'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showClouds'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'controlSun'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'controlTime'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSun'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeViewSize'
        QtMocHelpers::SlotData<void(QAction *)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'showFullScreen'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showStatusBar'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setupStatusBar'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setupDownloadProgressBar'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enterWhatsThis'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutMarble'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handbook'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openForum'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openEditBookmarkDialog'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setHome'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createBookmarksListMenu'
        QtMocHelpers::SlotData<void(QMenu *, const GeoDataContainer *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'lookAtBookmark'
        QtMocHelpers::SlotData<void(QAction *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 55 },
        }}),
        // Slot 'manageBookmarks'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createBookmarkMenu'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createFolderList'
        QtMocHelpers::SlotData<void(QMenu *, const GeoDataContainer *)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'showBookmarks'
        QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'downloadRegion'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showZoomLevel'
        QtMocHelpers::SlotData<void(bool)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'changeAngleDisplayUnit'
        QtMocHelpers::SlotData<void(QAction *)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 55 },
        }}),
        // Slot 'handleProgress'
        QtMocHelpers::SlotData<void(int, int)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'removeProgressItem'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN6Marble10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble10MainWindowE_t>.metaTypes,
    nullptr
} };

void Marble::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->showDistance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->showZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->showDateTime(); break;
        case 4: _t->initObject((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 5: _t->editSettings(); break;
        case 6: _t->updateSettings(); break;
        case 7: _t->fallBackToDefaultTheme(); break;
        case 8: _t->changeRecordingState(); break;
        case 9: _t->updateWindowTitle(); break;
        case 10: _t->updateCenterFromTheme(); break;
        case 11: _t->openFile(); break;
        case 12: _t->openMapDialog(); break;
        case 13: _t->exportMapScreenShot(); break;
        case 14: _t->showDownloadRegionDialog(); break;
        case 15: _t->printMapScreenShot(); break;
        case 16: _t->workOffline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->showMapWizard(); break;
        case 18: _t->copyMap(); break;
        case 19: _t->copyCoordinates(); break;
        case 20: _t->updateMapEditButtonVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->showMovieCaptureDialog(); break;
        case 22: _t->stopRecording(); break;
        case 23: _t->lockPosition((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->createPluginsMenus(); break;
        case 25: _t->createPluginMenus(); break;
        case 26: _t->showClouds((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->controlSun(); break;
        case 28: _t->controlTime(); break;
        case 29: _t->showSun((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->reload(); break;
        case 31: _t->changeViewSize((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 32: _t->showFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->showStatusBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setupStatusBar(); break;
        case 35: _t->setupDownloadProgressBar(); break;
        case 36: _t->enterWhatsThis(); break;
        case 37: _t->aboutMarble(); break;
        case 38: _t->handbook(); break;
        case 39: _t->openForum(); break;
        case 40: _t->openEditBookmarkDialog(); break;
        case 41: _t->setHome(); break;
        case 42: _t->createBookmarksListMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const GeoDataContainer*>>(_a[2]))); break;
        case 43: _t->lookAtBookmark((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 44: _t->manageBookmarks(); break;
        case 45: _t->createBookmarkMenu(); break;
        case 46: _t->createFolderList((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const GeoDataContainer*>>(_a[2]))); break;
        case 47: _t->showBookmarks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->downloadRegion(); break;
        case 49: _t->showZoomLevel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->changeAngleDisplayUnit((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 51: _t->handleProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 52: _t->removeProgressItem(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 50:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Marble::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int Marble::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    return _id;
}
QT_WARNING_POP
