/********************************************************************************
** Form generated from reading UI file 'TourWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOURWIDGET_H
#define UI_TOURWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QSlider>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TourWidget
{
public:
    QAction *m_actionMoveUp;
    QAction *m_actionMoveDown;
    QAction *m_actionDelete;
    QAction *m_actionNewTour;
    QAction *m_actionSaveTour;
    QAction *m_actionSaveTourAs;
    QAction *m_actionOpenTour;
    QAction *actionPlay;
    QAction *actionStop;
    QAction *m_actionRecord;
    QVBoxLayout *verticalLayout;
    QToolBar *m_toolBarControl;
    QListView *m_listView;
    QHBoxLayout *horizontalLayout;
    QToolBar *m_toolBarPlayback;
    QLabel *m_elapsedTime;
    QSlider *m_slider;
    QLabel *m_totalTime;

    void setupUi(QWidget *TourWidget)
    {
        if (TourWidget->objectName().isEmpty())
            TourWidget->setObjectName("TourWidget");
        TourWidget->resize(290, 234);
        m_actionMoveUp = new QAction(TourWidget);
        m_actionMoveUp->setObjectName("m_actionMoveUp");
        m_actionMoveUp->setEnabled(false);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/marble/go-up.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionMoveUp->setIcon(icon);
        m_actionMoveDown = new QAction(TourWidget);
        m_actionMoveDown->setObjectName("m_actionMoveDown");
        m_actionMoveDown->setEnabled(false);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/marble/go-down.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionMoveDown->setIcon(icon1);
        m_actionDelete = new QAction(TourWidget);
        m_actionDelete->setObjectName("m_actionDelete");
        m_actionDelete->setEnabled(false);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/marble/list-remove.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionDelete->setIcon(icon2);
        m_actionNewTour = new QAction(TourWidget);
        m_actionNewTour->setObjectName("m_actionNewTour");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/marble/document-new.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionNewTour->setIcon(icon3);
        m_actionSaveTour = new QAction(TourWidget);
        m_actionSaveTour->setObjectName("m_actionSaveTour");
        m_actionSaveTour->setEnabled(false);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/marble/document-save.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionSaveTour->setIcon(icon4);
        m_actionSaveTourAs = new QAction(TourWidget);
        m_actionSaveTourAs->setObjectName("m_actionSaveTourAs");
        m_actionSaveTourAs->setEnabled(false);
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/marble/document-save-as.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionSaveTourAs->setIcon(icon5);
        m_actionOpenTour = new QAction(TourWidget);
        m_actionOpenTour->setObjectName("m_actionOpenTour");
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/marble/document-open.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionOpenTour->setIcon(icon6);
        actionPlay = new QAction(TourWidget);
        actionPlay->setObjectName("actionPlay");
        actionPlay->setCheckable(false);
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/marble/playback-play.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionPlay->setIcon(icon7);
        actionStop = new QAction(TourWidget);
        actionStop->setObjectName("actionStop");
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/marble/playback-stop.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionStop->setIcon(icon8);
        m_actionRecord = new QAction(TourWidget);
        m_actionRecord->setObjectName("m_actionRecord");
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/marble/tour-capture.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionRecord->setIcon(icon9);
        verticalLayout = new QVBoxLayout(TourWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_toolBarControl = new QToolBar(TourWidget);
        m_toolBarControl->setObjectName("m_toolBarControl");

        verticalLayout->addWidget(m_toolBarControl);

        m_listView = new QListView(TourWidget);
        m_listView->setObjectName("m_listView");
        m_listView->setSelectionMode(QAbstractItemView::ExtendedSelection);

        verticalLayout->addWidget(m_listView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_toolBarPlayback = new QToolBar(TourWidget);
        m_toolBarPlayback->setObjectName("m_toolBarPlayback");

        horizontalLayout->addWidget(m_toolBarPlayback);

        m_elapsedTime = new QLabel(TourWidget);
        m_elapsedTime->setObjectName("m_elapsedTime");

        horizontalLayout->addWidget(m_elapsedTime);

        m_slider = new QSlider(TourWidget);
        m_slider->setObjectName("m_slider");
        m_slider->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(m_slider);

        m_totalTime = new QLabel(TourWidget);
        m_totalTime->setObjectName("m_totalTime");

        horizontalLayout->addWidget(m_totalTime);


        verticalLayout->addLayout(horizontalLayout);


        m_toolBarControl->addAction(m_actionNewTour);
        m_toolBarControl->addAction(m_actionOpenTour);
        m_toolBarControl->addAction(m_actionSaveTour);
        m_toolBarControl->addAction(m_actionSaveTourAs);
        m_toolBarControl->addSeparator();
        m_toolBarControl->addAction(m_actionMoveUp);
        m_toolBarControl->addAction(m_actionMoveDown);
        m_toolBarControl->addSeparator();
        m_toolBarControl->addAction(m_actionDelete);
        m_toolBarPlayback->addAction(actionPlay);
        m_toolBarPlayback->addSeparator();
        m_toolBarPlayback->addAction(actionStop);
        m_toolBarPlayback->addSeparator();
        m_toolBarPlayback->addAction(m_actionRecord);

        retranslateUi(TourWidget);

        QMetaObject::connectSlotsByName(TourWidget);
    } // setupUi

    void retranslateUi(QWidget *TourWidget)
    {
        TourWidget->setWindowTitle(QCoreApplication::translate("TourWidget", "Tour", nullptr));
        m_actionMoveUp->setText(QCoreApplication::translate("TourWidget", "Move up", nullptr));
#if QT_CONFIG(tooltip)
        m_actionMoveUp->setToolTip(QCoreApplication::translate("TourWidget", "Move up", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionMoveDown->setText(QCoreApplication::translate("TourWidget", "Move down", nullptr));
        m_actionDelete->setText(QCoreApplication::translate("TourWidget", "Delete", nullptr));
        m_actionNewTour->setText(QCoreApplication::translate("TourWidget", "New Tour", nullptr));
        m_actionSaveTour->setText(QCoreApplication::translate("TourWidget", "Save Tour", nullptr));
        m_actionSaveTourAs->setText(QCoreApplication::translate("TourWidget", "Save Tour As", nullptr));
        m_actionOpenTour->setText(QCoreApplication::translate("TourWidget", "Open Tour", nullptr));
        actionPlay->setText(QCoreApplication::translate("TourWidget", "Play", nullptr));
#if QT_CONFIG(tooltip)
        actionPlay->setToolTip(QCoreApplication::translate("TourWidget", "Begins touring", nullptr));
#endif // QT_CONFIG(tooltip)
        actionStop->setText(QCoreApplication::translate("TourWidget", "Stop", nullptr));
#if QT_CONFIG(tooltip)
        actionStop->setToolTip(QCoreApplication::translate("TourWidget", "Stops touring (playing again will start tour from the start)", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionRecord->setText(QCoreApplication::translate("TourWidget", "Record tour", nullptr));
#if QT_CONFIG(tooltip)
        m_actionRecord->setToolTip(QCoreApplication::translate("TourWidget", "Converts the loaded tour into a movie", nullptr));
#endif // QT_CONFIG(tooltip)
        m_toolBarControl->setWindowTitle(QCoreApplication::translate("TourWidget", "toolBar", nullptr));
        m_toolBarPlayback->setWindowTitle(QCoreApplication::translate("TourWidget", "toolBar", nullptr));
        m_elapsedTime->setText(QCoreApplication::translate("TourWidget", "--:--", nullptr));
        m_totalTime->setText(QCoreApplication::translate("TourWidget", "--:--", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TourWidget: public Ui_TourWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TOURWIDGET_H
