/********************************************************************************
** Form generated from reading UI file 'GoToDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GOTODIALOG_H
#define UI_GOTODIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>

QT_BEGIN_NAMESPACE

class Ui_GoTo
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *searchLineEdit;
    QPushButton *progressButton;
    QListView *bookmarkListView;
    QDialogButtonBox *buttonBox;
    QLabel *descriptionLabel;
    QHBoxLayout *horizontalLayout;
    QRadioButton *browseButton;
    QRadioButton *searchButton;

    void setupUi(QDialog *GoTo)
    {
        if (GoTo->objectName().isEmpty())
            GoTo->setObjectName("GoTo");
        GoTo->resize(368, 269);
        gridLayout = new QGridLayout(GoTo);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        searchLineEdit = new QLineEdit(GoTo);
        searchLineEdit->setObjectName("searchLineEdit");

        horizontalLayout_2->addWidget(searchLineEdit);

        progressButton = new QPushButton(GoTo);
        progressButton->setObjectName("progressButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(progressButton->sizePolicy().hasHeightForWidth());
        progressButton->setSizePolicy(sizePolicy);
        progressButton->setMinimumSize(QSize(32, 32));
        progressButton->setIconSize(QSize(32, 32));
        progressButton->setAutoDefault(false);
        progressButton->setFlat(true);

        horizontalLayout_2->addWidget(progressButton);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        bookmarkListView = new QListView(GoTo);
        bookmarkListView->setObjectName("bookmarkListView");
        bookmarkListView->setProperty("isWrapping", QVariant(false));
        bookmarkListView->setWordWrap(true);

        gridLayout->addWidget(bookmarkListView, 1, 0, 1, 1);

        buttonBox = new QDialogButtonBox(GoTo);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Vertical);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 1, 1, 1, 1);

        descriptionLabel = new QLabel(GoTo);
        descriptionLabel->setObjectName("descriptionLabel");
        descriptionLabel->setWordWrap(true);
        descriptionLabel->setOpenExternalLinks(true);

        gridLayout->addWidget(descriptionLabel, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        browseButton = new QRadioButton(GoTo);
        browseButton->setObjectName("browseButton");
        browseButton->setChecked(true);

        horizontalLayout->addWidget(browseButton);

        searchButton = new QRadioButton(GoTo);
        searchButton->setObjectName("searchButton");

        horizontalLayout->addWidget(searchButton);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 1);


        retranslateUi(GoTo);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, GoTo, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, GoTo, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(GoTo);
    } // setupUi

    void retranslateUi(QDialog *GoTo)
    {
        GoTo->setWindowTitle(QCoreApplication::translate("GoTo", "Go To\342\200\246", nullptr));
        progressButton->setText(QString());
        descriptionLabel->setText(QCoreApplication::translate("GoTo", "Enter a search term and press Enter. <a href=\"https://userbase.kde.org/Marble/Search\">Details\342\200\246</a>", nullptr));
        browseButton->setText(QCoreApplication::translate("GoTo", "Browse", nullptr));
        searchButton->setText(QCoreApplication::translate("GoTo", "Search", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GoTo: public Ui_GoTo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GOTODIALOG_H
