/********************************************************************************
** Form generated from reading UI file 'RoutinoConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROUTINOCONFIGWIDGET_H
#define UI_ROUTINOCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_RoutinoConfigWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *transport;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *fastest;
    QRadioButton *shortest;

    void setupUi(QWidget *RoutinoConfigWidget)
    {
        if (RoutinoConfigWidget->objectName().isEmpty())
            RoutinoConfigWidget->setObjectName("RoutinoConfigWidget");
        RoutinoConfigWidget->resize(273, 196);
        formLayout = new QFormLayout(RoutinoConfigWidget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(RoutinoConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        transport = new QComboBox(RoutinoConfigWidget);
        transport->setObjectName("transport");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, transport);

        groupBox = new QGroupBox(RoutinoConfigWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        fastest = new QRadioButton(groupBox);
        fastest->setObjectName("fastest");

        verticalLayout_2->addWidget(fastest);

        shortest = new QRadioButton(groupBox);
        shortest->setObjectName("shortest");

        verticalLayout_2->addWidget(shortest);


        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, groupBox);


        retranslateUi(RoutinoConfigWidget);

        QMetaObject::connectSlotsByName(RoutinoConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *RoutinoConfigWidget)
    {
        label->setText(QCoreApplication::translate("RoutinoConfigWidget", "Transport:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("RoutinoConfigWidget", "Method", nullptr));
        fastest->setText(QCoreApplication::translate("RoutinoConfigWidget", "Fastest", nullptr));
        shortest->setText(QCoreApplication::translate("RoutinoConfigWidget", "Shortest", nullptr));
        (void)RoutinoConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class RoutinoConfigWidget: public Ui_RoutinoConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ROUTINOCONFIGWIDGET_H
