/********************************************************************************
** Form generated from reading UI file 'TileLevelRangeWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TILELEVELRANGEWIDGET_H
#define UI_TILELEVELRANGEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TileLevelRangeWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_6;
    QLabel *tileLevelLabel;
    QSpinBox *topSpinBox;
    QLabel *toLabel;
    QSpinBox *bottomSpinBox;
    QSpacerItem *horizontalSpacer_8;

    void setupUi(QWidget *TileLevelRangeWidget)
    {
        if (TileLevelRangeWidget->objectName().isEmpty())
            TileLevelRangeWidget->setObjectName("TileLevelRangeWidget");
        TileLevelRangeWidget->resize(273, 92);
        verticalLayout = new QVBoxLayout(TileLevelRangeWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_2 = new QGroupBox(TileLevelRangeWidget);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        tileLevelLabel = new QLabel(groupBox_2);
        tileLevelLabel->setObjectName("tileLevelLabel");

        horizontalLayout_6->addWidget(tileLevelLabel);

        topSpinBox = new QSpinBox(groupBox_2);
        topSpinBox->setObjectName("topSpinBox");
        topSpinBox->setMinimum(0);
        topSpinBox->setMaximum(20);
        topSpinBox->setValue(0);

        horizontalLayout_6->addWidget(topSpinBox);

        toLabel = new QLabel(groupBox_2);
        toLabel->setObjectName("toLabel");

        horizontalLayout_6->addWidget(toLabel);

        bottomSpinBox = new QSpinBox(groupBox_2);
        bottomSpinBox->setObjectName("bottomSpinBox");
        bottomSpinBox->setMinimum(0);
        bottomSpinBox->setMaximum(20);
        bottomSpinBox->setValue(4);

        horizontalLayout_6->addWidget(bottomSpinBox);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_8);


        verticalLayout_2->addLayout(horizontalLayout_6);


        verticalLayout->addWidget(groupBox_2);

#if QT_CONFIG(shortcut)
        tileLevelLabel->setBuddy(topSpinBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(TileLevelRangeWidget);

        QMetaObject::connectSlotsByName(TileLevelRangeWidget);
    } // setupUi

    void retranslateUi(QWidget *TileLevelRangeWidget)
    {
        groupBox_2->setTitle(QCoreApplication::translate("TileLevelRangeWidget", "Zoom", nullptr));
        tileLevelLabel->setText(QCoreApplication::translate("TileLevelRangeWidget", "&Tile level range:", nullptr));
#if QT_CONFIG(tooltip)
        topSpinBox->setToolTip(QCoreApplication::translate("TileLevelRangeWidget", "Minimum Tile Level", nullptr));
#endif // QT_CONFIG(tooltip)
        toLabel->setText(QCoreApplication::translate("TileLevelRangeWidget", "to", nullptr));
#if QT_CONFIG(tooltip)
        bottomSpinBox->setToolTip(QCoreApplication::translate("TileLevelRangeWidget", "Maximum Tile Level", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)TileLevelRangeWidget;
    } // retranslateUi

};

namespace Ui {
    class TileLevelRangeWidget: public Ui_TileLevelRangeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TILELEVELRANGEWIDGET_H
